@@ -341,7 +341,10 @@ fors_dfs_set_groups(cpl_frameset * set)
                      strcmp(tag, "TELLURIC_CONTAMINATION"       ) == 0 ||
                      strcmp(tag, "STD_FLUX_TABLE"               ) == 0 ||
                      strcmp(tag, "SPECPHOT_TABLE"               ) == 0 ||
-                     strcmp(tag, PHOT_TABLE                     ) == 0) {
+                     strcmp(tag, PHOT_TABLE                     ) == 0 ||
+            		 strcmp(tag, PHOT_COEFF_TABLE               ) == 0 ||
+            		 strcmp(tag, STATIC_PHOT_COEFF_TABLE        ) == 0 ||
+            		 strcmp(tag, EXTINCTION_PER_NIGHT           ) == 0) {
                 cpl_frame_set_group(f, CPL_FRAME_GROUP_CALIB);
             }
             else {
@@ -366,7 +369,7 @@ fors_dfs_set_groups(cpl_frameset * set)
  * @return  newly allocated pipeline version string
  */
 /*----------------------------------------------------------------------------*/
-const char *
+char *
 fors_dfs_pipeline_version(const cpl_propertylist *header, 
                           const char **instrument_version)
 {
@@ -1091,6 +1094,12 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
     if(converter){
     	cpl_propertylist * idp_plist =
     			fors_dfs_idp_converter_generate_idp_propertylist(converter, plist);
+
+    	for(cpl_size i = 0; i < cpl_propertylist_get_size(idp_plist); ++i){
+    		const char * name = cpl_property_get_name(cpl_propertylist_get_const(idp_plist, i));
+    		cpl_propertylist_erase(plist, name);
+    	}
+
     	cpl_propertylist_append(plist, idp_plist);
     	cpl_propertylist_delete(idp_plist);
     }
@@ -1241,14 +1250,14 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
 
 /*----------------------------------------------------------------------------*/
 void
-fors_dfs_save_image_err_idp(cpl_frameset *frameset, const fors_image *image,
+fors_dfs_save_image_idp(cpl_frameset *frameset, const cpl_image *image,
                     const char *category, cpl_propertylist *header,
                     cpl_propertylist *err_header,
                     const cpl_parameterlist *parlist, const char *recipename,
                     const cpl_frame *inherit_frame,
 					const fors_dfs_idp_converter * converter){
 
-    dfs_save(frameset, image, FORS_TYPE_IMAGE_ERR,
+    dfs_save(frameset, image, FORS_TYPE_IMAGE,
              category, header, err_header,
              parlist, recipename,
              inherit_frame, converter);
@@ -1459,6 +1468,18 @@ fors_dfs_save_table(cpl_frameset *frameset, const cpl_table *table,
              inherit_frame, NULL);
 }
 
+void
+fors_dfs_save_table_idp(cpl_frameset *frameset, const cpl_table *table,
+                    const char *category, cpl_propertylist *header,
+                    const cpl_parameterlist *parlist, const char *recipename,
+                    const cpl_frame *inherit_frame, const fors_dfs_idp_converter * conv)
+{
+    dfs_save(frameset, table, FORS_TYPE_TABLE,
+             category, header, NULL,
+             parlist, recipename,
+             inherit_frame, conv);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
  * @brief
