@@ -444,6 +444,7 @@ extract_sex(                                const fors_image *image,
     const char *const filename_sigma = "sextract_bkg_sigma.fits";
     const char *const filename_cat   = "sextract_cat.fits";
     const char *const filename_bkg   = "sextract_bkg.fits";
+    const char *const filename_minus_obj   = "sextract_minus_obj.fits";
     cpl_table *out = NULL;
     const char *command = NULL;
     fors_star_list *stars = NULL;
@@ -546,8 +547,8 @@ extract_sex(                                const fors_image *image,
                                            unit = e- / ADU
                                         */
                           "-PIXEL_SCALE %f "
-                          "-CHECKIMAGE_TYPE BACKGROUND "
-                          "-CHECKIMAGE_NAME %s "
+                          "-CHECKIMAGE_TYPE BACKGROUND,-OBJECTS "
+                          "-CHECKIMAGE_NAME %s,%s "
                           "-WEIGHT_TYPE MAP_RMS "
                           "-WEIGHT_IMAGE %s,%s "
                           "-CATALOG_TYPE FITS_1.0 "
@@ -557,7 +558,7 @@ extract_sex(                                const fors_image *image,
                           sex_config,
                           1.0/setting->average_gain,
                           setting->pixel_scale,
-                          filename_bkg,
+						  filename_bkg, filename_minus_obj,
                           filename_sigma, filename_sigma,
                           filename_cat);
 
@@ -570,12 +571,16 @@ extract_sex(                                const fors_image *image,
      * and is also returned to the caller.
      */
     {
-        int plane = 0;
-        int extension = 0;
+
+    	const int plane = 0;
+        const int extension = 0;
 
         *background = cpl_image_load(filename_bkg,
                                      CPL_TYPE_FLOAT, plane, extension);
 
+        cpl_image * minus_objs = cpl_image_load(filename_minus_obj,
+        		CPL_TYPE_FLOAT, plane, extension);
+
         assure( !cpl_error_get_code(), return NULL,
                 "Could not load SExtractor background image %s",
                 filename_bkg );
@@ -625,14 +630,17 @@ extract_sex(                                const fors_image *image,
         cpl_image_subtract_scalar(work_back, sky_stats->median);
         cpl_image_abs(work_back);
         sky_stats->rms    = cpl_image_get_median_window(work_back, 
-                                                        xlo, ylo, xhi, yhi)
-                          * STDEV_PR_MAD;
+                                                        xlo, ylo, xhi, yhi) * STDEV_PR_MAD;;
+
+        sky_stats->bkg_rms = cpl_image_get_stdev_window(minus_objs, xlo, ylo, xhi, yhi);
 
         cpl_image_delete(work_back); work_back = NULL;
 
         assure( !cpl_error_get_code(), return NULL,
                 "Could not calculate sky statistics" );
 
+        cpl_image_delete(minus_objs);
+
     }
     
     cpl_msg_info(cpl_func, "Background = %f +- %f ADU",
@@ -782,7 +790,9 @@ extract_sex(                                const fors_image *image,
                                             "THETA_IMAGE", 
                                             sex_mag,
                                             sex_magerr,
-                                            "CLASS_STAR");
+                                            "CLASS_STAR",
+											"FLUX_APER",
+											"FLUX_MAX");
             (*s).orientation *= M_PI/180;
             (*s).semi_major *= setting->binx;
             (*s).semi_minor *= setting->binx;
@@ -850,7 +860,8 @@ extract_sex(                                const fors_image *image,
     }
     status += unlink(filename_cat);
     status += unlink(filename_bkg);
- 
+    status += unlink(filename_minus_obj);
+
     assure( status == 0, return NULL,
             "Problem removing temporary files");
     
