@@ -24,7 +24,12 @@
 #include "cpl.h"
 #include "grism_config.h"
 
-std::auto_ptr<mosca::grism_config> fors_grism_config_from_frame
-(cpl_frame * grism_frame, double wave_ref);
+std::unique_ptr<mosca::grism_config> fors_grism_config_from_frame
+(cpl_frame * grism_frame, const double wave_ref,
+        const double start_wave = NAN, const double stop_wave = NAN);
+
+std::unique_ptr<mosca::grism_config> fors_grism_config_from_table
+(const cpl_table * grism_table , const double wave_ref,
+        const double start_wave = NAN, const double stop_wave = NAN);
 
 #endif /* FORS_GRISM_H_ */
