@@ -1771,9 +1771,16 @@ hdrl_imagelist * fors_image_list_to_hdrl(const fors_image_list * imalist)
     {
         const cpl_image * ima_data  = target->data;
         cpl_image * ima_error = cpl_image_power_create(target->variance, 0.5);
-        cpl_mask * old_bpm = cpl_image_set_bpm(ima_error, 
-                               cpl_mask_duplicate(cpl_image_get_bpm_const(ima_data)));
-        cpl_mask_delete(old_bpm);
+
+        //Set the same mask for image and its associated error
+        //This is required by hdrl_image.
+        cpl_mask * ima_mask = cpl_image_get_bpm_const(ima_data);
+        cpl_mask * imaerr_mask = NULL;
+        if(ima_mask != NULL)
+            imaerr_mask = cpl_mask_duplicate(ima_mask);
+        cpl_mask * old_bpm = cpl_image_set_bpm(ima_error, imaerr_mask);
+        if(old_bpm != NULL)
+            cpl_mask_delete(old_bpm);
         hdrl_image * ima_hdrl = hdrl_image_create(ima_data, ima_error);
         hdrl_imagelist_set(images_hdrl, ima_hdrl, 
                            hdrl_imagelist_get_size(images_hdrl));
