@@ -45,6 +45,7 @@
 #include <fors_subtract_bias.h>
 #include "fors_bpm.h"
 #include "fors_dfs_idp.h"
+#include "fors_img_idp.h"
 
 #include <cpl.h>
 #include <math.h>
@@ -67,16 +68,20 @@ const char *const fors_img_science_description =
 "  SCIENCE_IMG                Raw         Science image               			 1\n"
 "  MASTER_BIAS                FITS image  Master bias                 			 1\n"
 "  MASTER_SKY_FLAT_IMG        FITS image  Master sky flat field       			 1\n"
-//"  PHOT_COEFF_TABLE           FITS table  Observed extinction coefficients       0+\n"
-//"  ALIGNED_PHOT           	  FITS table  Frame Zeropoint        				 0+\n"
+"  PHOT_COEFF_TABLE           FITS table  Observed extinction coefficients       0+\n"
+"  EXTINCTION_PER_NIGHT       FITS table  Extinction per night      			 0+\n"
+"  STATIC_PHOT_COEFF_TABLE    FITS table  Static filters coefficients     		 0+\n"
+
 "\n"
 "Output files:\n"
 "  DO category:               Data type:  Explanation:\n"
 "  SCIENCE_REDUCED_IMG        FITS image  Reduced science image\n"
 "  PHOT_BACKGROUND_SCI_IMG    FITS image  Reduced science image background\n"
 "  SOURCES_SCI_IMG            FITS image  Unfiltered SExtractor output\n"
-"  OBJECT_TABLE_SCI_IMG       FITS table  Extracted sources properties\n";
-
+"  OBJECT_TABLE_SCI_IMG       FITS table  Extracted sources properties\n"
+"  SCIENCE_REDUCED_IMG_IDP    FITS image  Reduced science image in IDP-compliant format\n"
+"  SCIENCE_REDUCED_WEIGHT_IDP FITS image  Ancillary file with the weights for IDP the image\n"
+"  SCIENCE_REDUCED_ERR_IDP    FITS image  Ancillary file with the errors for IDP the image\n";
 
 static double
 get_image_quality(const fors_star_list *sources, double *image_quality_err,
@@ -84,9 +89,11 @@ get_image_quality(const fors_star_list *sources, double *image_quality_err,
                   double *ellipticity,
                   double *ellipticity_rms);
 
-static fors_dfs_idp_converter *
-generate_imaging_idp_converter(const cpl_frame * bias_frame,
-		const cpl_frame * phot_frame, const fors_image * sci);
+static const
+fors_img_idp_tags IDP_Products_Filenames(SCIENCE_REDUCED_IMG_IDP, SCIENCE_REDUCED_WEG_IDP,
+	SCIENCE_REDUCED_ERR_IDP, fors_img_science_name);
+
+
 
 /**
  * @brief    Define recipe parameters
@@ -100,20 +107,6 @@ void fors_img_science_define_parameters(cpl_parameterlist *parameters)
     char *full_name = NULL;
     const char *name;
 
-    /*  This parameter is not yet implemented
-    name = "cr_remove";
-    full_name = cpl_sprintf("%s.%s", context, name);
-    p = cpl_parameter_new_value(full_name,
-                                CPL_TYPE_BOOL,
-                                "Cosmic ray removal",
-                                context,
-                                false);
-    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, name);
-    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
-    cpl_parameterlist_append(parameters, p);
-    cpl_free((void *)full_name); full_name = NULL;
-    */
-
     name = "magsyserr";
     full_name = cpl_sprintf("%s.%s", context, name);
     p = cpl_parameter_new_value(full_name,
@@ -127,20 +120,46 @@ void fors_img_science_define_parameters(cpl_parameterlist *parameters)
     cpl_free((void *)full_name); full_name = NULL;
 
     fors_extract_define_parameters(parameters, context);
-    
+
+
+    name = "idp_generate";
+    full_name = cpl_sprintf("%s.%s", context, name);
+    p = cpl_parameter_new_value(full_name,
+                                CPL_TYPE_BOOL,
+                                "If TRUE compliant IDP science "
+                                "products are generated",
+                                context,
+                                CPL_FALSE);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, name);
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(parameters, p);
+    cpl_free((void *)full_name); full_name = NULL;
+
+    name = "idp_weights_threshold";
+    full_name = cpl_sprintf("%s.%s", context, name);
+    p = cpl_parameter_new_value(full_name,
+                                CPL_TYPE_DOUBLE,
+                                "Every pixel in the MASTER_SKY_FLAT_IMG below "
+                                "the threshold will be put to 0 in the weight-map, "
+                                "1 otherwise. Ignored if IDP generation is not requested",
+                                context,
+                                0.5);
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, name);
+    cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
+    cpl_parameterlist_append(parameters, p);
+    cpl_free((void *)full_name); full_name = NULL;
+
     cpl_free((void *)context);
 
     return;
 }
 
-
 #undef cleanup
 #define cleanup \
 do { \
     cpl_frameset_delete(sci_frame); \
     cpl_frameset_delete(master_bias_frame); \
     cpl_frameset_delete(master_flat_frame); \
-    cpl_frameset_delete(phot_table); \
     fors_image_delete(&sci); \
     fors_image_delete(&master_bias); \
     fors_image_delete(&master_flat); \
@@ -180,8 +199,6 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     fors_image *master_flat         = NULL; 
 
 
-    cpl_frameset *phot_table        = NULL;
-
     /* Products */
     cpl_propertylist *qc = cpl_propertylist_new();
     cpl_propertylist *product_header = cpl_propertylist_new();
@@ -212,6 +229,17 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     magsyserr = dfs_get_parameter_double_const(parameters,
                                                name);
     cpl_free((void *)name); name = NULL;
+
+    cpl_msg_indent_more();
+    name = cpl_sprintf("%s.%s", context, "idp_generate");
+    bool generate_idp = dfs_get_parameter_bool_const(parameters, name);
+    cpl_free((void *)name); name = NULL;
+
+    cpl_msg_indent_more();
+    name = cpl_sprintf("%s.%s", context, "idp_weights_threshold");
+    const double idp_weights_threshold = dfs_get_parameter_double_const(parameters, name);
+    cpl_free((void *)name); name = NULL;
+
     cpl_msg_indent_less();
     assure( !cpl_error_get_code(), return, NULL );
     assure( magsyserr >= 0, return, 
@@ -221,45 +249,21 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Find raw */
     sci_frame = fors_frameset_extract(frames, SCIENCE_IMG);
     assure( cpl_frameset_get_size(sci_frame) == 1, return, 
-            "Exactly 1 %s required. %"CPL_SIZE_FORMAT" found", 
+            "Exactly 1 %s required. %" CPL_SIZE_FORMAT" found", 
             SCIENCE_IMG, cpl_frameset_get_size(sci_frame) );
 
     /* Find calibration */
     master_bias_frame = fors_frameset_extract(frames, MASTER_BIAS);
     assure( cpl_frameset_get_size(master_bias_frame) == 1, return, 
-            "One %s required. %"CPL_SIZE_FORMAT" found", 
+            "One %s required. %" CPL_SIZE_FORMAT" found", 
             MASTER_BIAS, cpl_frameset_get_size(master_bias_frame) );
 
     master_flat_frame = fors_frameset_extract(frames, MASTER_SKY_FLAT_IMG);
     assure( cpl_frameset_get_size(master_flat_frame) == 1, return, 
-            "One %s required. %"CPL_SIZE_FORMAT" found", 
+            "One %s required. %" CPL_SIZE_FORMAT" found", 
             MASTER_SKY_FLAT_IMG, cpl_frameset_get_size(master_flat_frame) );
 
 
-    phot_table = fors_frameset_extract(frames, PHOT_COEFF_TABLE);
-    cpl_frameset *zp_table = fors_frameset_extract(frames, ALIGNED_PHOT);
-
-    if(cpl_frameset_get_size(phot_table) == 0 && cpl_frameset_get_size(zp_table) == 0){
-    	//cpl_msg_warning(cpl_func, "Unable to extract %s or %s . Photometry IDP keywords"
-		//    			" will not be produced.", PHOT_COEFF_TABLE, ALIGNED_PHOT);
-    	cpl_frameset_delete(phot_table);
-    	phot_table = NULL;
-    	cpl_frameset_delete(zp_table);
-    	zp_table = NULL;
-    } else if(cpl_frameset_get_size(phot_table) != 0){
-    	//    	cpl_msg_info(cpl_func, "Found %s. Photometry IDP keywords"
-    	//   			" will be produced.", PHOT_COEFF_TABLE);
-    	cpl_frameset_delete(zp_table);
-    	zp_table = NULL;
-    } else{
-    	//cpl_msg_info(cpl_func, "%s was not found, but %s was found. Photometry IDP keywords"
-    	//    	    			" will be produced.", PHOT_COEFF_TABLE, ALIGNED_PHOT);
-    	cpl_frameset_delete(phot_table);
-    	phot_table = NULL;
-    	phot_table = zp_table;
-    	zp_table = NULL;
-    }
-
     /* Done finding frames */
 
     /* Get instrument setting */
@@ -303,7 +307,10 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
         overscan_levels = fors_get_bias_levels_from_overscan(sci_raw, ccd_config);
     else
         overscan_levels = fors_get_bias_levels_from_mbias(master_bias, ccd_config);
-    fors_image_variance_from_detmodel(sci_raw, ccd_config, overscan_levels);
+
+    double average_overscan_level = 0;
+    fors_image_variance_from_detmodel(sci_raw, ccd_config, overscan_levels,
+    		&average_overscan_level);
     
     /*Subtract overscan */
     if(perform_preoverscan)
@@ -339,7 +346,6 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     fors_image_divide(sci, master_flat);
     assure( !cpl_error_get_code(), return, "Could not divide by master flat");
-    fors_image_delete(&master_flat);
 
     /* Extract sources */
     stars = fors_extract(sci, setting, em, magsyserr,
@@ -414,6 +420,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
                                              &ellipticity,
                                              &ellipticity_rms);
 
+
     if (image_quality > 0.) {
         image_quality *= TWOSQRT2LN2 * setting->pixel_scale;
         image_quality_error *= TWOSQRT2LN2 * setting->pixel_scale;
@@ -485,18 +492,30 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     const cpl_frame * inherit_frame = cpl_frameset_get_position_const(sci_frame, 0);
 
-    const cpl_frame * phot_frame = phot_table ?
-    		cpl_frameset_get_position_const(phot_table, 0) : NULL;
+    if(generate_idp){
 
-    fors_dfs_idp_converter * converter =
-    generate_imaging_idp_converter(cpl_frameset_get_frame(master_bias_frame, 0),
-    		phot_frame, sci);
+    	double image_fswm = 0;
+    	const bool fwhm_available = fors_img_idp_get_image_psf_fwhm(stars, setting, header, &image_fswm);
 
-    fors_dfs_save_image_err_idp(frames, sci, SCIENCE_REDUCED_IMG,
+    	if(fwhm_available){
+
+    		fors_img_idp_quality qty(image_fswm, ellipticity,
+    		    sky_stats.bkg_rms, sky_mag, average_overscan_level, sources);
+
+    		fors_img_idp_save(frames, sci, qc, parameters,
+    			inherit_frame, cpl_frameset_get_position(master_bias_frame, 0),
+				master_flat, idp_weights_threshold, IDP_Products_Filenames,
+				qty);
+    	}
+    	else{
+    		cpl_msg_warning(cpl_func, "Unable to calculate PSF_FWHM, aborting IDP generation");
+    		cpl_error_reset();
+    	}
+    }
+
+    fors_dfs_save_image_err(frames, sci, SCIENCE_REDUCED_IMG,
                         qc, NULL, parameters, fors_img_science_name, 
-						inherit_frame, NULL);
-
-    fors_dfs_idp_converter_delete(converter);
+						inherit_frame);
 
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             SCIENCE_REDUCED_IMG);
@@ -511,33 +530,11 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     cpl_image_delete(background); background = NULL;
     
-    /* Load filter coefficients */
-
-/* %%%
-    fors_phot_table_load(cpl_frameset_get_first(phot_table), setting,
-                         NULL, NULL, 
-			 &ext_coeff, &dext_coeff,
-			 NULL, NULL);
-    assure( !cpl_error_get_code(), return, "Could not load photometry table" );
-*/
-
-    /* Correct for atmospheric extinction */
-/* %%%
-    fors_star_ext_corr(stars, setting, ext_coeff, dext_coeff,
-                       cpl_frameset_get_first(sci_frame));
-    assure( !cpl_error_get_code(), return, 
-            "Extinction correction failed");
-*/
-
     /* Create, save FITS product */
     phot = fors_create_sources_table(stars);
     assure( !cpl_error_get_code(), return,
             "Failed to create extracted sources table");
 
-    /*
-     * Eliminate unused columns from photometry table
-     */
-
     cpl_table_erase_column(phot, "INSTR_CMAG");
     cpl_table_erase_column(phot, "DINSTR_CMAG");
     cpl_table_erase_column(phot, "OBJECT");
@@ -559,8 +556,9 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_table_erase_column(phot, "WEIGHT");
 
     fors_dfs_save_table(frames, sources, SOURCES_SCI,
-                        NULL, parameters, fors_img_science_name, 
+    		NULL, parameters, fors_img_science_name,
                         cpl_frameset_get_position(sci_frame, 0));
+
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             SOURCES_SCI);
 
@@ -594,11 +592,15 @@ is_star(const fors_star *s, void *data)
     return s->stellarity_index >= 0.7;
 }
 
+
 #undef cleanup
 #define cleanup \
 do { \
     fors_star_list_delete(&stars, fors_star_delete); \
 } while(0)
+
+
+
 /**
  * @brief    Compute image quality
  * @param    sources             extracted sources
@@ -650,24 +652,5 @@ get_image_quality(const fors_star_list *sources, double *image_quality_err,
     return fwhm;
 }
 
-static fors_dfs_idp_converter *
-generate_imaging_idp_converter(const cpl_frame * bias_frame,
-		const cpl_frame * phot_frame, const fors_image * sci){
-
-	cpl_propertylist * bias_plist = cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
-
-	if(bias_plist == NULL) return NULL;
-
-	cpl_propertylist * phot_plist = NULL;
-	if(phot_frame)
-		phot_plist = cpl_propertylist_load(cpl_frame_get_filename(phot_frame), 0);
-
-	fors_dfs_idp_converter * to_ret =
-	fors_generate_imaging_idp_converter(bias_plist, phot_plist, sci);
-
-	cpl_propertylist_delete(bias_plist);
-	cpl_propertylist_delete(phot_plist);
-	return to_ret;
-}
 
 /**@}*/
