@@ -42,13 +42,6 @@ extern const char *const fors_img_science_description;
 void fors_img_science_define_parameters(cpl_parameterlist *parameters);
 void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters);
 
-cpl_propertylist * fors_img_science_add_IDP_keywords(
-		const cpl_propertylist * qc_plist,
-		const cpl_propertylist * father_plist,
-		const cpl_propertylist * bias_plist,
-		const cpl_propertylist * phot_coeff_plist,
-		const fors_image * img,
-		const char * raw_name);
 CPL_END_DECLS
 
 #endif
