@@ -224,3 +224,71 @@ void fors_trimm_fix_wcs(cpl_propertylist * header)
     cpl_propertylist_update_double(header, "CRPIX2",
         cpl_propertylist_get_double(header, "CRPIX2") - crop_region_1.lly() + 1);
 }
+
+bool fors_is_preoverscan_empty(const mosca::ccd_config& ccd_config)
+{
+    for(size_t iport = 0; iport < ccd_config.nports(); iport++)
+    {
+        if(!ccd_config.prescan_region(iport).is_empty() ||
+           !ccd_config.overscan_region(iport).is_empty())
+            return false;
+    }
+    
+    return true;
+}
+
+bool fors_is_master_bias_preoverscan_corrected(cpl_propertylist * mbias_header)
+{
+    if(cpl_propertylist_has(mbias_header, "ESO QC BIAS OVSC_SUB"))
+    {
+        if(cpl_propertylist_get_bool(mbias_header, "ESO QC BIAS OVSC_SUB"))
+            return true;
+        else 
+            return false;
+    }
+    
+    //The absence of the keyword implies that the master bias was created
+    //with a version of the pipeline that didn't support images without
+    //pre/overscan (PIPE-5643).
+    return true; 
+}
+
+std::vector<double> fors_get_bias_levels_from_overscan
+(fors_image *image, const mosca::ccd_config& ccd_config)
+{
+    std::vector<double> overscan_level; 
+    //Loop on each port:
+    for(size_t iport = 0; iport < ccd_config.nports(); iport++)
+    {
+        mosca::rect_region ps_reg = 
+                ccd_config.prescan_region(iport).coord_0to1();
+        if(ps_reg.is_empty())
+            throw std::invalid_argument("Prescan area is empty. Cannot compute "
+                    "detector noise model");
+
+        double os_level = cpl_image_get_median_window
+          (image->data, ps_reg.llx(), ps_reg.lly(), ps_reg.urx(), ps_reg.ury());
+        
+        overscan_level.push_back(os_level);
+    }
+    return overscan_level;
+}
+
+std::vector<double> fors_get_bias_levels_from_mbias
+(fors_image *mbias, const mosca::ccd_config& ccd_config)
+{
+    std::vector<double> overscan_level; 
+    //Loop on each port:
+    for(size_t iport = 0; iport < ccd_config.nports(); iport++)
+    {
+        mosca::rect_region valid_port_reg = 
+                ccd_config.validpix_region(iport).coord_0to1();
+        
+        double os_level = cpl_image_get_median_window
+          (mbias->data, valid_port_reg.llx(), valid_port_reg.lly(), 
+                  valid_port_reg.urx(), valid_port_reg.ury());
+        
+        overscan_level.push_back(os_level);
+    }
+    return overscan_level;
+}
