@@ -51,4 +51,15 @@ void fors_trimm_preoverscan(cpl_mask *& mask,
 void fors_trimm_fill_info(cpl_propertylist * header,
                           const mosca::ccd_config& ccd_config);
 
+void fors_trimm_fix_wcs(cpl_propertylist * header);
+
+bool fors_is_preoverscan_empty(const mosca::ccd_config& ccd_config);
+
+bool fors_is_master_bias_preoverscan_corrected(cpl_propertylist * mbias_header);
+
+std::vector<double> fors_get_bias_levels_from_overscan(fors_image *image, 
+                                       const mosca::ccd_config& ccd_config);
+
+std::vector<double> fors_get_bias_levels_from_mbias(fors_image *mbias, 
+                                       const mosca::ccd_config& ccd_config);
 #endif   /* FORS_OVERSCAN_H */
