@@ -153,17 +153,19 @@ fors_star *fors_star_new(double x, double y,
 #define cleanup fors_star_delete(&s)
 /**
  * @brief   Create a star from a table WITHOUT checking
- * @param   tab         Input table
- * @param   row         Input row index
- * @param   x_col       (Optional) x column name
- * @param   y_col       (Optional) y column name
- * @param   fwhm_col    (Optional) fwhm column name
- * @param   smaj_col    (Optional) s_major column name
- * @param   smin_col    (Optional) s_minor column name
- * @param   theta_col   (Optional) orientation column name
- * @param   mag_col     (Optional) magnitude column name
- * @param   dmag_col    (Optional) magnitude error column name
- * @param   stlndx_col  (Optional) stellar index column name
+ * @param   tab         	Input table
+ * @param   row         	Input row index
+ * @param   x_col       	(Optional) x column name
+ * @param   y_col      		(Optional) y column name
+ * @param   fwhm_col    	(Optional) fwhm column name
+ * @param   smaj_col    	(Optional) s_major column name
+ * @param   smin_col    	(Optional) s_minor column name
+ * @param   theta_col   	(Optional) orientation column name
+ * @param   mag_col     	(Optional) magnitude column name
+ * @param   dmag_col    	(Optional) magnitude error column name
+ * @param   stlndx_col  	(Optional) stellar index column name
+ * @param   flux_aper_col  	(Optional) flux aperture column name
+ * @param   flux_max_col  	(Optional) flux max column name
  * @return  newly allocated star
  */
 /*----------------------------------------------------------------------------*/
@@ -177,9 +179,10 @@ fors_star *fors_star_new_from_table(const cpl_table *tab,
                                     const char      *theta_col,
                                     const char      *mag_col,
                                     const char      *dmag_col,
-                                    const char      *stlndx_col)
+                                    const char      *stlndx_col,
+									const char 		*flux_aper_col,
+									const char 		*flux_max_col)
 {
-    int null;
     fors_star *s = cpl_malloc(sizeof(*s));
 
     s->pixel = fors_point_new(  _get_optional_table_value(tab, row, x_col),
@@ -207,6 +210,12 @@ fors_star *fors_star_new_from_table(const cpl_table *tab,
     s->dmagnitude =             _get_optional_table_value(tab, row, dmag_col);
     assure(!cpl_error_get_code(), return s, NULL);
     
+    s->flux_aper =              _get_optional_table_value(tab, row, flux_aper_col);
+    assure(!cpl_error_get_code(), return s, NULL);
+
+    s->flux_max =               _get_optional_table_value(tab, row, flux_max_col);
+    assure(!cpl_error_get_code(), return s, NULL);
+
     s->magnitude_corr = 0;
     s->dmagnitude_corr = 0;
     s->id = NULL;
@@ -371,6 +380,23 @@ double fors_star_extension(const fors_star *s, void *data)
     return s->fwhm / TWOSQRT2LN2;
 }
 
+#undef cleanup
+#define cleanup
+/**
+ * @brief  Get star fwhm
+ * @param  s      star
+ * @param  data   not used
+ * @return  average extension (one sigma)
+ */
+/*----------------------------------------------------------------------------*/
+double fors_star_fwhm(const fors_star *s, void *data)
+{
+    assure( s != NULL, return -1, NULL );
+    data = data;
+
+    return s->fwhm ;
+}
+
 /*----------------------------------------------------------------------------*/
 #undef cleanup
 #define cleanup
