@@ -299,7 +299,8 @@ fors_fixed_pattern_noise(const fors_image *master,
     }
     else {
         cpl_msg_warning(cpl_func,
-                        "Master flat too small (%dx%d), "
+                        "Master flat too small (%"CPL_SIZE_FORMAT"x%"
+                        CPL_SIZE_FORMAT"), "
                         "need size 121x121 to compute master flat "
                         "fixed pattern noise",
                         fors_image_get_size_x(master),
