@@ -813,4 +813,15 @@ double fors_utils_median_corr(int n)
     }
 }
 
+/**
+ * @brief  get valid error code in case of exit
+ * @return the current error code or CPL_ERROR_UNSPECIFIED if no error has been set
+ */
+cpl_error_code fors_get_error_for_exit(void)
+{
+	const cpl_error_code fail = cpl_error_get_code();
+	if(fail) return fail;
+	return CPL_ERROR_UNSPECIFIED;
+}
+
 /**@}*/
