@@ -73,7 +73,6 @@ get_stddevs_from_raws(const cpl_frame ** frames){
     return m;
 }
 
-
 static inline double
 get_mean_from_raws(const cpl_frame ** frames){
 
@@ -148,6 +147,8 @@ test_dark(void)
     fors_setting *setting = NULL;
 
     /* Simulate data */
+    const int number_saturated[] = {1, 2, 1};
+    const int number_total_of_saturated = 1 + 2 + 1;
     const char *dark_filename[] = {"dark_1.fits",
                                    "dark_2.fits",
                                    "dark_3.fits"};
@@ -160,7 +161,7 @@ test_dark(void)
         for (i = 0; i < sizeof(dark_filename)/sizeof(char *); i++) {
 
             cpl_frame * f = create_dark(dark_filename[i],
-                    DARK, CPL_FRAME_GROUP_RAW);
+                    DARK, CPL_FRAME_GROUP_RAW, number_saturated[i]);
 
             cpl_frameset_insert(frames, 
                                 f);
@@ -245,12 +246,10 @@ test_dark(void)
             test(cpl_error_get_code() == CPL_ERROR_NONE);
             test_rel(raw_mean_of_stddevs, get_stddevs_from_raws(darks), 1e-10);
 
-
-
-            const long long master_n_badpix = cpl_propertylist_get_long_long(list,
-                        "ESO QC DARK NBADPX");
+            const long long raw_n_badpix = cpl_propertylist_get_long_long(list,
+                        "ESO QC DARK RAW NBADPX");
             test(cpl_error_get_code() == CPL_ERROR_NONE);
-            test(master_n_badpix ==  cpl_image_count_rejected(master_dark->data));
+            test(raw_n_badpix ==  number_total_of_saturated);
 
             double master_median = cpl_propertylist_get_double(list,
                         "ESO QC DARK MEDIAN");
