@@ -300,9 +300,9 @@ test_dfs_load(void)
 	const char* tab_tag 			  = "PHOT_TAG";
 	const char* tab_not_existing_tag  = "PHOT_TABLE_NOT_EXISTING";
 
-	const char* bias_fname = "master_bias.fits";
-	const char* sky_flat_fname = "master_sky_flat.fits";
-	const char* table_fname = "phot_table.fits";
+	const char* bias_fname = "master_bias_dfs_test.fits";
+	const char* sky_flat_fname = "master_sky_flat_dfs_test.fits";
+	const char* table_fname = "phot_table_dfs_test.fits";
 
 	cpl_frame* f1 = create_bias(bias_fname, bias_tag, CPL_FRAME_GROUP_CALIB);
 	cpl_frame* f2 = create_sky_flat(sky_flat_fname, flat_tag,
@@ -330,6 +330,7 @@ test_dfs_load(void)
 
 	assure(cpl_error_get_code() != CPL_ERROR_NONE, return,
 			"Load image: CPL error not set");
+
 	cpl_error_reset();
 
 	assure(img1, return,  "Img1 must be correctly extracted");
@@ -377,7 +378,7 @@ static void test_dfs_proplist_add(void)
 
 	fors_setting* setting = NULL;
 
-	const char* fname = "skyflat.fits";
+	const char* fname = "skyflat_dfs_test.fits";
 	const char* tag = "SKY_FLAT";
 
 	double expTime = 987.0f;
@@ -456,13 +457,17 @@ static void test_dfs_proplist_add(void)
 
 void test_dfs_equal_keywords()
 {
-	const char* bias_fname = "bias.fits";
-	const char* flat_fname = "flat.fits";
-
+	const char* bias_fname = "bias_dfs_test.fits";
+	const char* flat_fname = "flat_dfs_test.fits";
 
 	cpl_frameset* f_set = get_fset_kwords(CPL_TRUE, CPL_TRUE, bias_fname,
 			flat_fname);
 
+	for(cpl_size i = 0; i < cpl_frameset_get_size(f_set); ++i){
+		const char * fname = cpl_frame_get_filename(cpl_frameset_get_position_const(f_set, i));
+		cpl_msg_warning(cpl_func, "file for test: %s", fname);
+	}
+
 	assure(f_set, return,
 			"Generation of frameset for test failed");
 
@@ -474,7 +479,7 @@ void test_dfs_equal_keywords()
 				"TEST_PROP_INT should be equal!");
 
 	assure(!dfs_equal_keyword(f_set, "TEST_PROP_FLOAT"), return,
-				"TEST_PROP_INT should be NEVER equal!");
+				"TEST_PROP_FLOAT should be NEVER equal!");
 
 	cleanup;
 
@@ -489,7 +494,7 @@ void test_dfs_equal_keywords()
 				"TEST_PROP_INT should be NOT equal!");
 
 	assure(!dfs_equal_keyword(f_set, "TEST_PROP_FLOAT"), return,
-				"TEST_PROP_INT should be NEVER equal!");
+				"TEST_PROP_FLOAT should be NEVER equal!");
 
 	cleanup;
 
@@ -504,7 +509,7 @@ void test_dfs_equal_keywords()
 				"TEST_PROP_INT should be NOT equal!");
 
 	assure(!dfs_equal_keyword(f_set, "TEST_PROP_FLOAT"), return,
-				"TEST_PROP_INT should be NEVER equal!");
+				"TEST_PROP_FLOAT should be NEVER equal!");
 
 	assure(dfs_equal_keyword(f_set, "TEST_PROP_NOT_EXISTING_STRING"), return,
 					"Not existing property should be treated as found!");
@@ -593,6 +598,8 @@ add_keyword(cpl_frame* frame, cpl_boolean use_val1)
 	cpl_propertylist* l =
 			cpl_propertylist_load(fname, 0);
 
+	cpl_test_eq_error(CPL_ERROR_NONE, cpl_error_get_code());
+
 	//supported
 	cpl_propertylist_append_string(l, "TEST_PROP_STRING", use_val1 ?
 			"testString1" : "testString2");
@@ -605,6 +612,8 @@ add_keyword(cpl_frame* frame, cpl_boolean use_val1)
 	cpl_propertylist_save(l, fname, CPL_IO_CREATE);
 
 	cpl_propertylist_delete(l);
+
+	cpl_test_eq_error(CPL_ERROR_NONE, cpl_error_get_code());
 }
 
 static void
@@ -658,11 +667,19 @@ int main(void)
     
     test_dfs_get_parameters();
 
+    cpl_test_eq_error(cpl_error_get_code(), CPL_ERROR_NONE);
+
     test_dfs_load();
 
+    cpl_test_eq_error(cpl_error_get_code(), CPL_ERROR_NONE);
+
     test_dfs_proplist_add();
 
+    cpl_test_eq_error(cpl_error_get_code(), CPL_ERROR_NONE);
+
     test_dfs_equal_keywords();
 
+    cpl_test_eq_error(cpl_error_get_code(), CPL_ERROR_NONE);
+
     TEST_END;
 }
