@@ -35,6 +35,7 @@
 
 #include <test_simulate.h>
 #include <test.h>
+#include <fs_test.h>
 
 #include <cpl.h>
 
@@ -53,6 +54,9 @@ do { \
     fors_image_delete(&master_sflat); \
     fors_image_delete(&master_bias); \
     fors_setting_delete(&setting); \
+    delete_test_files(sky_flat_filename);\
+    delete_test_file(master_name );\
+    delete_test_file_from_tag(MASTER_SKY_FLAT_IMG);\
 } while(0)
 
 /**
@@ -76,6 +80,8 @@ test_img_sky_flat(void)
     const char *sky_flat_filename[] = {"img_sky_flat_1.fits",
                                        "img_sky_flat_2.fits",
                                        "img_sky_flat_3.fits"};
+    const char* master_name = "img_sky_flat_master_bias.fits";
+
 
     double sky_flat_exptime[] = {1, 2, 5};
     {
@@ -94,7 +100,7 @@ test_img_sky_flat(void)
     setting = fors_setting_new(cpl_frameset_get_position(frames, 0));
     
     cpl_frameset_insert(frames, 
-                        create_master_bias("img_sky_flat_master_bias.fits", 
+                        create_master_bias(master_name,
                                     MASTER_BIAS, CPL_FRAME_GROUP_CALIB));
 
     fors_img_sky_flat_define_parameters(parameters);
