@@ -278,93 +278,7 @@ test_rel_macro(double first,  const char *first_string,
 }
 
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief   Initialize CPL + messaging
-  @param   file     filename
-  @note    This function should be called only by using the macro
-           TEST_INIT
- */
-/*----------------------------------------------------------------------------*/
-void
-test_init_macro(const char *file)
-{
-    /* Build message domain + log filename
-       from source file name */
-    
-    unsigned len = strlen(file);
-    int able_to_parse_filename;
 
-    cpl_init(CPL_INIT_DEFAULT);
-    error_init = cpl_errorstate_get();
-    srand(0);
-
-    if (len < strlen("s.c") || strcmp(file + len - strlen(".c"), ".c") != 0)
-        {
-            able_to_parse_filename = 0;
-            /* Here, we should issue a warning but we need to
-               initialize the CPL message system first */
-        }
-    else
-        {
-            /* Form domain from filename by removing ".c" suffix
-               and stripping any path prefix */
-
-            const char dir_delimiter = '/'; /* UNIX only! */
-            unsigned path_length = 0;       /* Length of path prefix 
-                                               including final '/' */
-            int i;
-
-            for (i = len - strlen(".c") - 1; i >= 0; i--)
-                {
-                    if (file[i] == dir_delimiter && path_length == 0)
-                        {
-                            path_length = i + 1;
-                        }
-                }
-            
-            able_to_parse_filename = (len - path_length - strlen(".c") >= 1);
-            if (able_to_parse_filename)
-                {
-                    const char *logfile;
-                    char *domain;
-
-                    domain = cpl_strdup(file + path_length);
-                    domain[len - path_length - strlen(".c")] = '\0';
-
-                    cpl_msg_set_domain(domain);
-                    
-                    logfile = cpl_sprintf("%s.log", domain);
-                    cpl_msg_set_log_name(logfile);
-                    
-                    cpl_free((char *)logfile);
-                    cpl_free(domain);
-                }
-            /* else: Use default domain + logfilename */
-        }
-
-    /* Adopt the policy that the unit test is quiet
-       unless something is wrong.
-       Dump debugging info to the log file */
-    cpl_msg_set_level(CPL_MSG_WARNING); 
-    cpl_msg_set_log_level(CPL_MSG_DEBUG);
-    
-    if (!able_to_parse_filename)
-        {
-            cpl_msg_warning(cpl_func,
-                            "Source file name '%s' does not match [base].c. ",
-                            file);
-        }
-
-    if (cpl_error_get_code() != CPL_ERROR_NONE)
-        {
-            cpl_msg_error(cpl_func,
-                          "Failure during initialization: %s at %s",
-                          cpl_error_get_message(), cpl_error_get_where());
-        }
-
-    return;
-}
 
 /*----------------------------------------------------------------------------*/
 /**
