@@ -315,16 +315,18 @@ do { \
 
 /**
  * @brief   Simulate dark image
- * @param   filename        save to this file
- * @param   tag             output frame tag
- * @param   tag             output frame group
+ * @param   filename         save to this file
+ * @param   tag              output frame tag
+ * @param   tag              output frame group
+ * @param   number_saturated number of saturated pixels
  * @return  dark frame
  *
  * Model:     bias   + dark(x,y)
  * Variance = ron**2 + dark(x,y)/conad
  */
 cpl_frame *
-create_dark(const char *filename, const char *tag, cpl_frame_group group)
+create_dark(const char *filename, const char *tag,
+		cpl_frame_group group, const int number_saturated)
 {
     int nx = det_nx / binx + pres_nx;
     int ny = det_ny / biny;
@@ -339,14 +341,24 @@ create_dark(const char *filename, const char *tag, cpl_frame_group group)
 
     {
         int x, y;
+        int num_sat = 0;
         for (y = 1; y <= ny; y++)
             for (x = 1; x <= nx; x++) {
-                double var = ron*ron + dark_avg/conad;
+                const double var = ron*ron + dark_avg/conad;
+                double val = (int)(bias_avg + dark_avg +
+                        sqrt(var)*fors_rand_gauss()
+                        + 0.5);
+
+                if(num_sat < number_saturated && x > pres_nx){
+                	num_sat ++;
+                	if(num_sat % 2)
+                		val = 65000;
+                	else
+                		val = 0.23;
+                }
+
+                cpl_image_set(data, x, y, val);
                 
-                cpl_image_set(data   , x, y, 
-                              (int)(bias_avg + dark_avg + 
-                                    sqrt(var)*fors_rand_gauss() 
-                                    + 0.5));
                 cpl_image_set(variance, x, y, var);
             }
         //Fill the prescan region
@@ -359,6 +371,8 @@ create_dark(const char *filename, const char *tag, cpl_frame_group group)
             }
     }
     
+
+
     dark = fors_image_new(data, variance);
     fors_image_save(dark, header, NULL, filename);
 
