@@ -49,6 +49,7 @@
 
 #include "hdrl_image.h"
 #include "hdrl_imagelist.h"
+#include "hdrl_parameter.h"
 #include "hdrl_imagelist_view.h"
 #include "hdrl_overscan.h"
 #include "hdrl_buffer.h"
@@ -60,5 +61,11 @@
 #include "hdrl_bpm_utils.h"
 #include "hdrl_fit.h"
 #include "hdrl_strehl.h"
-
+#include "hdrl_flat.h"
+#include "hdrl_catalogue.h"
+#include "hdrl_random.h"
+#include "hdrl_iter.h"
+#include "hdrl_frameiter.h"
+#include "hdrl_multiiter.h"
+#include "hdrl_fringe.h"
 #endif 
