@@ -55,8 +55,8 @@ struct _hdrl_iter_ {
     hdrl_iter_length_f * length;
     /* state destructor */
     hdrl_free * destructor;
-    /* iterator type */
-    hdrl_iter_type_t type;
+    /* iterator flags */
+    hdrl_iter_flags flags;
     /* state structure of iterator */
     void * state;
 };
@@ -69,7 +69,7 @@ struct _hdrl_iter_ {
  * @param next   function pointer returning next value in sequence iterated on
  * @param reset  function pointer or NULL, reseting iteration to first element
  * @param length function pointer or NULL, returning length of sequence
- * @param type   type of iterator
+ * @param flag   flags of iterator
  * @param state  state structure of iterator
  *
  * An iterator iterates on a sequence of data (e.g. imagelist, files on
@@ -97,27 +97,27 @@ hdrl_iter_init(hdrl_iter_next_f * next,
                   hdrl_iter_reset_f * reset,
                   hdrl_iter_length_f * length,
                   hdrl_free * destructor,
-                  hdrl_iter_type_t type,
+                  hdrl_iter_flags flags,
                   void * state)
 {
     /* exactly one each set */
-    hdrl_iter_type_t inout = (HDRL_ITER_INPUT | HDRL_ITER_OUTPUT);
-    hdrl_iter_type_t rettype = (HDRL_ITER_IMAGE | HDRL_ITER_IMAGELIST);
-    cpl_ensure(((type & inout) == HDRL_ITER_INPUT) ||
-               ((type & inout) == HDRL_ITER_OUTPUT),
+    hdrl_iter_flags inout = (HDRL_ITER_INPUT | HDRL_ITER_OUTPUT);
+    hdrl_iter_flags retflags = (HDRL_ITER_IMAGE | HDRL_ITER_IMAGELIST);
+    cpl_ensure(((flags & inout) == HDRL_ITER_INPUT) ||
+               ((flags & inout) == HDRL_ITER_OUTPUT),
                CPL_ERROR_ILLEGAL_INPUT, NULL);
-    cpl_ensure(((type & rettype) == HDRL_ITER_IMAGE) ||
-               ((type & rettype) == HDRL_ITER_IMAGELIST),
+    cpl_ensure(((flags & retflags) == HDRL_ITER_IMAGE) ||
+               ((flags & retflags) == HDRL_ITER_IMAGELIST),
                CPL_ERROR_ILLEGAL_INPUT, NULL);
     cpl_ensure(state, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(next, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(type != 0, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(flags != 0, CPL_ERROR_NULL_INPUT, NULL);
     hdrl_iter * it = cpl_malloc(sizeof(*it));
     it->next = next;
     it->length = length;
     it->reset = reset;
     it->destructor = destructor ? destructor : &cpl_free;
-    it->type = type;
+    it->flags = flags;
     it->state = state;
     return it;
 }
@@ -140,13 +140,13 @@ void * hdrl_iter_state(hdrl_iter * it)
  * @internal
  * @brief check if iterator has a certain flag
  * @param it iterator
- * @param type flag to check
+ * @param flags flag to check
  * @return true or false depending wheter iterator has flags set
  */
 /* ---------------------------------------------------------------------------*/
-cpl_boolean hdrl_iter_check(hdrl_iter * it, hdrl_iter_type_t type)
+cpl_boolean hdrl_iter_check(hdrl_iter * it, hdrl_iter_flags flags)
 {
-    return (it->type & type) == type;
+    return (it->flags & flags) == flags;
 }
 
 /** @endcond */
@@ -163,7 +163,7 @@ void hdrl_iter_delete(hdrl_iter * it)
 {
     if (it) {
         if (it->destructor) {
-            it->destructor(it->state);
+            it->destructor(it);
         }
         cpl_free(it);
     }
@@ -194,7 +194,7 @@ void hdrl_iter_reset(hdrl_iter * it)
                               "Iterator has no reset method");
         return;
     }
-    return it->reset(it);
+    it->reset(it);
 }
 
 /* ---------------------------------------------------------------------------*/
