@@ -347,16 +347,12 @@ cpl_mask * hdrl_lacosmic_edgedetect(
     cpl_image * sci_data = NULL;
     cpl_image * sci_error = NULL;
     cpl_mask  * sci_mask = NULL;
-    cpl_image * laplacian_data = NULL;
     cpl_image * laplacian_redu_data = NULL; /* re-binned Laplacian */
     cpl_image * subs2_data = NULL; /* Sub-sampled image by a factor of 2 */
-    cpl_image * s_median_data = NULL;
     cpl_image * s_data = NULL;
     cpl_image * f_data = NULL;
     cpl_image * r_data = NULL;
 
-    cpl_image * sci_median3_data = NULL;
-    cpl_image * sci_median3_7_data = NULL;
 
     intptr_t subs2_nx = 0;
     intptr_t subs2_ny = 0;
@@ -392,6 +388,11 @@ cpl_mask * hdrl_lacosmic_edgedetect(
     cpl_ensure(hdrl_lacosmic_parameter_verify(params) == CPL_ERROR_NONE,
             CPL_ERROR_ILLEGAL_INPUT, NULL) ;
 
+    cpl_ensure(hdrl_image_get_size_x(ima_in) >= 7,
+               CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+    cpl_ensure(hdrl_image_get_size_y(ima_in) >= 7,
+               CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+
     /* Local Usage parameters */
     const hdrl_lacosmic_parameter * p_loc = (hdrl_lacosmic_parameter *)params ;
 
@@ -509,7 +510,7 @@ cpl_mask * hdrl_lacosmic_edgedetect(
          -1   4  -1
           0  -1   0 */
 
-        laplacian_data = hdrl_parallel_filter_image(subs2_data,
+        cpl_image * laplacian_data = hdrl_parallel_filter_image(subs2_data,
                                                     laplacian_kernel, NULL,
                                                     CPL_FILTER_LINEAR);
 
@@ -570,7 +571,7 @@ HDRL_OMP(omp parallel for)
 #endif
 
         /* A) compute S median image */
-        s_median_data = hdrl_parallel_filter_image(s_data, NULL,
+        cpl_image * s_median_data = hdrl_parallel_filter_image(s_data, NULL,
                                                    median5_kernel,
                                                    CPL_FILTER_MEDIAN);
         ps_median_data = cpl_image_get_data_double( s_median_data);
@@ -587,16 +588,18 @@ HDRL_OMP(omp parallel for)
 #endif
 
         /* Apply 3x3 median filter on data */
-        sci_median3_data = hdrl_parallel_filter_image(sci_data, NULL,
-                                                      median3_kernel,
-                                                      CPL_FILTER_MEDIAN);
+        cpl_image * sci_median3_data =
+            hdrl_parallel_filter_image(sci_data, NULL,
+                                       median3_kernel,
+                                       CPL_FILTER_MEDIAN);
         psci_median3_data = cpl_image_get_data_double(sci_median3_data);
 
         /* Apply 7x7 median filter */
 
-        sci_median3_7_data = hdrl_parallel_filter_image(sci_median3_data, NULL,
-                                                        median7_kernel,
-                                                        CPL_FILTER_MEDIAN);
+        cpl_image * sci_median3_7_data =
+            hdrl_parallel_filter_image(sci_median3_data, NULL,
+                                       median7_kernel,
+                                       CPL_FILTER_MEDIAN);
         psci_median3_7_data = cpl_image_get_data_double(sci_median3_7_data);
 
         /* C) Compute F, i.e. the fine structure image */
