@@ -1,5 +1,4 @@
-/* $Id: hdrl_overscan.c,v 1.43 2013-10-23 09:13:56 jtaylor Exp $
- *
+/* 
  * This file is part of the HDRL
  * Copyright (C) 2012,2013 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author: jtaylor $
- * $Date: 2013-10-23 09:13:56 $
- * $Revision: 1.43 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -58,7 +50,7 @@ static cpl_error_code  hdrl_overscan_compute_chi_square(const cpl_image *,
         const cpl_image *, const double, double *, double *);
 static cpl_error_code hdrl_overscan_reduce_image_to_scalar(
         hdrl_collapse_imagelist_to_vector_t *, cpl_image *, cpl_image *, 
-        double *, double *, cpl_size *, void *) ;
+        double *, double *, cpl_size *, void **) ;
 static void hdrl_overscan_parameter_destroy(void * param);
 
 /*----------------------------------------------------------------------------*/
@@ -168,29 +160,6 @@ hdrl_parameter * hdrl_overscan_parameter_create(
     return (hdrl_parameter *)p;
 }
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Update Overscan Parameters object
-  @param    overscan                The overscan parameters to update
-  @param    correction_direction    HDRL_X_AXIS or HDRL_Y_AXIS
-  @param    ccd_ron                 The CCD read out noise
-  @param    box_hsize               The running box half size
-  @return   the error code in case of error or CPL_ERROR_NONE
- */
-/*----------------------------------------------------------------------------*/
-cpl_error_code hdrl_overscan_parameter_update(
-        hdrl_parameter  *   overscan,
-        hdrl_direction      correction_direction,
-        double              ccd_ron,
-        int                 box_hsize)
-{
-    hdrl_overscan_parameter * p = (hdrl_overscan_parameter *)overscan ;
-    p->correction_direction = correction_direction ;
-    p->ccd_ron = ccd_ron ;
-    p->box_hsize = box_hsize ;
-    return hdrl_overscan_parameter_verify(overscan, -1, -1);
-}
-
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Verify basic correctness of the Overscan parameters
@@ -205,7 +174,6 @@ cpl_error_code hdrl_overscan_parameter_verify(
         cpl_size                    nx,
         cpl_size                    ny) 
 {
-    cpl_size    region_llx, region_lly, region_urx, region_ury ;
     const hdrl_overscan_parameter * param_loc = 
         (hdrl_overscan_parameter *)param ;
 
@@ -235,6 +203,13 @@ cpl_error_code hdrl_overscan_parameter_verify(
                 return CPL_ERROR_ILLEGAL_INPUT,
                 "Illegal Collapse Sigclip parameters");
     } 
+    if (hdrl_collapse_parameter_is_minmax(param_loc->collapse)) {
+        cpl_error_ensure(
+                hdrl_collapse_minmax_parameter_verify(param_loc->collapse)
+                == CPL_ERROR_NONE, CPL_ERROR_ILLEGAL_INPUT,
+                return CPL_ERROR_ILLEGAL_INPUT,
+                "Illegal Collapse Minmax parameters");
+    } 
     cpl_error_ensure(
             hdrl_rect_region_parameter_verify(param_loc->rect_region, -1, -1)
             == CPL_ERROR_NONE, CPL_ERROR_ILLEGAL_INPUT,
@@ -242,15 +217,18 @@ cpl_error_code hdrl_overscan_parameter_verify(
             "Illegal Rect Region parameters");
 
     cpl_error_ensure(hdrl_collapse_parameter_is_mean(param_loc->collapse) ||
+            hdrl_collapse_parameter_is_weighted_mean(param_loc->collapse) ||
             hdrl_collapse_parameter_is_median(param_loc->collapse) ||
-            hdrl_collapse_parameter_is_sigclip(param_loc->collapse),
+            hdrl_collapse_parameter_is_sigclip(param_loc->collapse) ||
+            hdrl_collapse_parameter_is_minmax(param_loc->collapse),
             CPL_ERROR_ILLEGAL_INPUT, return CPL_ERROR_ILLEGAL_INPUT,
-            "Only supported methods are MEAN, MEDIAN and SIGCLIP");
+            "Only supported methods are MEAN, WEIGHTED_MEAN, MEDIAN, SIGCLIP,"
+            " and MINMAX");
 
     /* The region must be contained in the image */
     if (nx > 0) {
-        region_llx = hdrl_rect_region_get_llx(param_loc->rect_region) ;
-        region_urx = hdrl_rect_region_get_urx(param_loc->rect_region) ;
+        cpl_size region_llx = hdrl_rect_region_get_llx(param_loc->rect_region);
+        cpl_size region_urx = hdrl_rect_region_get_urx(param_loc->rect_region);
         cpl_error_ensure(
                 region_llx>=1 && region_urx <= nx,
                 CPL_ERROR_ILLEGAL_INPUT, return CPL_ERROR_ILLEGAL_INPUT, 
@@ -258,8 +236,8 @@ cpl_error_code hdrl_overscan_parameter_verify(
                 (int)region_urx, (int)nx);
     }
     if (ny > 0) {
-        region_lly = hdrl_rect_region_get_lly(param_loc->rect_region) ;
-        region_ury = hdrl_rect_region_get_ury(param_loc->rect_region) ;
+        cpl_size region_lly = hdrl_rect_region_get_lly(param_loc->rect_region);
+        cpl_size region_ury = hdrl_rect_region_get_ury(param_loc->rect_region);
         cpl_error_ensure(
                 region_lly>=1 && region_ury <= ny,
                 CPL_ERROR_ILLEGAL_INPUT, return CPL_ERROR_ILLEGAL_INPUT, 
@@ -358,15 +336,18 @@ hdrl_parameter * hdrl_overscan_parameter_get_rect_region(
   @param rect_region_def default overscan region parameters
   @param method_def      default collapse method value
   @param sigclip_def     default sigma-clipping parameters 
+  @param minmax_def      default minmax-clipping parameters 
 
   @see hdrl_rect_region_parameter_create_parlist()
   @see hdrl_collapse_parameter_create_parlist()
-  Creates a parameterlist with the overscan computation parameters
-    base_context.prefix.correction-direction
-    base_context.prefix.box-hsize
-    base_context.prefix.ccd-ron
-    base_context.prefix.calc-*
-    base_context.prefix.collapse.*
+  Creates a parameterlist with the overscan computation parameters:
+
+    - base_context.prefix.correction-direction
+    - base_context.prefix.box-hsize
+    - base_context.prefix.ccd-ron
+    - base_context.prefix.calc-*
+    - base_context.prefix.collapse.*
+
   The CLI aliases omit the base_context.
  */
 /* ---------------------------------------------------------------------------*/
@@ -378,7 +359,8 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
         double              ccd_ron_def,
         hdrl_parameter  *   rect_region_def,
         const char      *   method_def,
-        hdrl_parameter  *   sigclip_def)
+        hdrl_parameter  *   sigclip_def,
+        hdrl_parameter  *   minmax_def)
 {
     cpl_ensure(prefix && base_context, CPL_ERROR_NULL_INPUT, NULL);
     char                *   name ;
@@ -399,14 +381,12 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
     cpl_parameterlist_append(parlist, par);
  
     /* --prefix.box-hsize */
-    hdrl_setup_vparameter(parlist, prefix, ".", "",
-            "box-hsize", base_context,
+    hdrl_setup_vparameter(parlist, prefix, ".", "", "box-hsize", base_context,
             "Half size of running box in pixel, -1 for full overscan region", 
             CPL_TYPE_INT, box_hsize_def) ;
 
     /* --prefix.ccd-ron */
-    hdrl_setup_vparameter(parlist, prefix, ".", "",
-            "ccd-ron", base_context,
+    hdrl_setup_vparameter(parlist, prefix, ".", "", "ccd-ron", base_context,
             "Readout noise in ADU", CPL_TYPE_DOUBLE, ccd_ron_def) ;
 
     /* Create Overscan Computation Region parameters */
@@ -422,7 +402,7 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
     /* --prefix.collapse.xxx */
     name = hdrl_join_string(".", 2, prefix, "collapse");
     cpl_parameterlist * pcollapse = hdrl_collapse_parameter_create_parlist(
-            base_context, name, method_def, sigclip_def) ;
+            base_context, name, method_def, sigclip_def, minmax_def) ;
     cpl_free(name);
     for (cpl_parameter * p = cpl_parameterlist_get_first(pcollapse) ;
             p != NULL; p = cpl_parameterlist_get_next(pcollapse))
@@ -446,18 +426,21 @@ cpl_parameterlist * hdrl_overscan_parameter_create_parlist(
   @param prefix     prefix of parameter name
   @return   Input parameters for the Overscan Computation
   Reads a Parameterlist in order to create overscan parameters.
-  Expects a parameterlist containing
-  --prefix.correction-direction 
-  --prefix.box-hsize 
-  --prefix.ccd-ron  
-  --prefix.calc-llx 
-  --prefix.calc-lly 
-  --prefix.calc-urx 
-  --prefix.calc-ury 
-  --prefix.collapse.method 
-  --prefix.collapse.sigclip.kappa-low 
-  --prefix.collapse.sigclip.kappa-high 
-  --prefix.collapse.sigclip.niter 
+  Expects a parameterlist containing:
+  - prefix.correction-direction
+  - prefix.box-hsize
+  - prefix.ccd-ron
+  - prefix.calc-llx
+  - prefix.calc-lly
+  - prefix.calc-urx
+  - prefix.calc-ury
+  - prefix.collapse.method
+  - prefix.collapse.sigclip.kappa-low
+  - prefix.collapse.sigclip.kappa-high
+  - prefix.collapse.sigclip.niter
+  - prefix.collapse.minmax.nlow
+  - prefix.collapse.sigclip.nhigh
+
  */
 /* ---------------------------------------------------------------------------*/
 hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
@@ -479,9 +462,9 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
     par = cpl_parameterlist_find_const(parlist, name) ;
     correction_direction = cpl_parameter_get_string(par);
     if (correction_direction == NULL) {
-        cpl_free(name);
         cpl_error_set_message(cpl_func, CPL_ERROR_DATA_NOT_FOUND,
                               "Parameter %s not found", name);
+        cpl_free(name);
         return NULL;
     }
     if(!strcmp(correction_direction, "alongX")) {
@@ -531,6 +514,52 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
     }
 }
 
+/* ---------------------------------------------------------------------------*/
+/**
+ * @brief get imagelist to vector reduction object
+ *
+ * @param cpse              parameter that determines the reduction type
+ * @param overscan_sub_ima  overscan image for default parameters
+ * @param reduce            pointer to reduction object storage
+ * @return cpl_error_code
+ *
+ * pointer stored in reduce must be deleted with
+ * hdrl_collapse_imagelist_to_vector_delete()
+ */
+/* ---------------------------------------------------------------------------*/
+static cpl_error_code
+get_reduction(const hdrl_parameter * cpse,
+              const cpl_image * overscan_sub_ima,
+              hdrl_collapse_imagelist_to_vector_t ** reduce)
+{
+    if (hdrl_collapse_parameter_is_mean(cpse)) {
+        *reduce = hdrl_collapse_imagelist_to_vector_mean();
+    } else if (hdrl_collapse_parameter_is_weighted_mean(cpse)) {
+        *reduce = hdrl_collapse_imagelist_to_vector_weighted_mean();
+    } else if (hdrl_collapse_parameter_is_median(cpse)) {
+        *reduce = hdrl_collapse_imagelist_to_vector_median();
+    } else if (hdrl_collapse_parameter_is_sigclip(cpse)) {
+        double kappa =
+            sqrt(log(CX_MAX(hdrl_get_image_good_npix(overscan_sub_ima), 1)));
+        double kappa_low = hdrl_collapse_sigclip_parameter_get_kappa_low(cpse);
+        double kappa_high =
+            hdrl_collapse_sigclip_parameter_get_kappa_high(cpse);
+        int niter = hdrl_collapse_sigclip_parameter_get_niter(cpse);
+        if (kappa_low <= 0)     kappa_low = kappa;
+        if (kappa_high <= 0)    kappa_high = kappa;
+        *reduce = hdrl_collapse_imagelist_to_vector_sigclip(kappa_low,
+                                                            kappa_high, niter);
+    } else if (hdrl_collapse_parameter_is_minmax(cpse)) {
+        double nlow = hdrl_collapse_minmax_parameter_get_nlow(cpse);
+        double nhigh = hdrl_collapse_minmax_parameter_get_nhigh(cpse);
+        if (nlow <= 0)     nlow = 0;
+        if (nhigh <= 0)    nhigh = 0;
+        *reduce = hdrl_collapse_imagelist_to_vector_minmax(nlow, nhigh);
+    }
+
+    return cpl_error_get_code();
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Overscan correction computation
@@ -576,7 +605,7 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
   must be strictly non-negative. It is used for the error, the chi2 and the
   red_chi2 computation.
 
-  In case the sgma-clipping collapsing method is used, a sigma clipping
+  In case the sigma-clipping collapsing method is used, a sigma clipping
   iterative rejection is applied in the overscan sub-window before the 
   computation of the results.
 
@@ -588,7 +617,7 @@ hdrl_parameter * hdrl_overscan_parameter_parse_parlist(
   pixels of the running sub-window (mean, median or mean after rejection, 
   depending on the used collapsing method)
 
-  Itis error contains \f$\frac{ccd\_ron}{\sqrt{contribution}}\f$ for the 
+  Its error contains \f$\frac{ccd\_ron}{\sqrt{contribution}}\f$ for the
   mean, weighted mean and sigma-cliping methods.
   In case the method is the median one, it would contain 
   \f$\sqrt{\frac{\pi}{2}}\times\frac{ccd\_ron}{\sqrt{contribution}}\f$
@@ -628,17 +657,15 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
     cpl_image   *   contribution_img = NULL;
     cpl_image   *   chi2_img = NULL;
     cpl_image   *   red_chi2_img = NULL;
-    cpl_image   *   sigclip_reject_low = NULL;
-    cpl_image   *   sigclip_reject_high = NULL;
+    cpl_image   *   reject_low = NULL;
+    cpl_image   *   reject_high = NULL;
     cpl_size        llx = 0;
     cpl_size        lly = 0;
     cpl_size        urx = 0;
     cpl_size        ury = 0;
-    cpl_image   *   ccd_ron_ima = NULL;
     cpl_image   *   overscan_ima = NULL;
-    hdrl_collapse_imagelist_to_vector_t * reduce = NULL;
-    hdrl_sigclip_vector_output sigclipout;
-    void * collapse_eout = NULL;
+
+     /*TODO add minmax description to the doxygen */
 
     /* Check Entries */
     cpl_error_ensure(source != NULL, CPL_ERROR_NULL_INPUT, 
@@ -657,17 +684,6 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
     const hdrl_parameter * cpse = p_loc->collapse ;
     const hdrl_parameter * rr = p_loc->rect_region ;
 
-    /* Switch on the different methods */
-    if (hdrl_collapse_parameter_is_mean(cpse)) {
-        reduce = hdrl_collapse_imagelist_to_vector_mean();
-    } else if (hdrl_collapse_parameter_is_median(cpse)) {
-        reduce = hdrl_collapse_imagelist_to_vector_median();
-    } else if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-        collapse_eout = &sigclipout;
-    } else {
-        abort(); /* checked earlier */
-    }
-
     /* Extract Overscan region */
     overscan_ima = cpl_image_extract(source, 
             hdrl_rect_region_get_llx(rr),
@@ -694,13 +710,16 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
     chi2_img = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
     red_chi2_img = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
 
-    if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-        sigclip_reject_low = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
-        sigclip_reject_high = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
+    if (hdrl_collapse_parameter_is_sigclip(cpse) ||
+                    hdrl_collapse_parameter_is_minmax(cpse)) {
+        reject_low = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
+        reject_high = cpl_image_new(1, ury, CPL_TYPE_DOUBLE);
     }
 
+
     /* Loop along Y direction */
     /* only 1 iteration if hbox == HDRL_OVERSCAN_FULL_BOX */
+HDRL_OMP(omp parallel for)
     for (long ipixel = 1;
          ipixel <= (p_loc->box_hsize == HDRL_OVERSCAN_FULL_BOX ? 1 : ury);
          ipixel++) {
@@ -710,7 +729,10 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         const double ccd_ron = p_loc->ccd_ron;
         cpl_size upperlimit;
         cpl_size lowerlimit;
-        cpl_image * overscan_sub_ima;
+        cpl_image * overscan_sub_ima, * ccd_ron_ima;
+        /* Switch on the different methods */
+        hdrl_collapse_imagelist_to_vector_t * reduce = NULL;
+        void * collapse_eout = NULL;
 
         /* define proper extraction limits */
         if (box_hsize == HDRL_OVERSCAN_FULL_BOX) {
@@ -738,59 +760,48 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         cpl_image_multiply_scalar(ccd_ron_ima, 0.0);
         cpl_image_add_scalar(ccd_ron_ima, ccd_ron);
 
-        if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-            hdrl_collapse_imagelist_to_vector_delete(reduce);
-            double kappa =
-                sqrt(log(CX_MAX(hdrl_get_image_good_npix(overscan_sub_ima), 1)));
-            double kappa_low = 
-                hdrl_collapse_sigclip_parameter_get_kappa_low(cpse);
-            double kappa_high =
-                hdrl_collapse_sigclip_parameter_get_kappa_high(cpse);
-            int niter = hdrl_collapse_sigclip_parameter_get_niter(cpse);
-            if (kappa_low <= 0)     kappa_low = kappa;
-            if (kappa_high <= 0)    kappa_high = kappa;
-            reduce = hdrl_collapse_imagelist_to_vector_sigclip(kappa_low,
-                    kappa_high, niter);
-        }
+        get_reduction(cpse, overscan_sub_ima, &reduce);
+
         /* Compute the over-scan correction, error, and contribution  */
         hdrl_overscan_reduce_image_to_scalar(reduce, overscan_sub_ima, 
-                ccd_ron_ima, &corr, &error, &contribution, collapse_eout);
-        /* handle additional sigclip output */
-        if (collapse_eout) {
-            double low = cpl_vector_get(sigclipout.reject_low, 0);
-            double high = cpl_vector_get(sigclipout.reject_high, 0);
-            cpl_image_set(sigclip_reject_low, 1, ipixel, low);
-            cpl_image_set(sigclip_reject_high, 1, ipixel, high);
-            cpl_vector_delete(sigclipout.reject_low);
-            cpl_vector_delete(sigclipout.reject_high);
+                ccd_ron_ima, &corr, &error, &contribution, &collapse_eout);
+        /* handle additional sigclip and minmax output */
+        if (collapse_eout && (hdrl_collapse_parameter_is_sigclip(cpse) ||
+            hdrl_collapse_parameter_is_minmax(cpse))) {
+            assert(sizeof(hdrl_sigclip_vector_output) ==
+                   sizeof(hdrl_minmax_vector_output));
+            hdrl_sigclip_vector_output * eout = collapse_eout;
+            double low = cpl_vector_get(eout->reject_low, 0);
+            double high = cpl_vector_get(eout->reject_high, 0);
+            cpl_image_set(reject_low, 1, ipixel, low);
+            cpl_image_set(reject_high, 1, ipixel, high);
+            cpl_vector_delete(eout->reject_low);
+            cpl_vector_delete(eout->reject_high);
         }
+        hdrl_collapse_imagelist_to_vector_unwrap_eout(reduce, collapse_eout);
 
         /* Compute the chi2 - Independent of the method */
-        if (contribution == 0){
+        if (contribution == 0) {
             chi2 = NAN;
             red_chi2 = NAN;
-        }
-        else if (p_loc->box_hsize == HDRL_OVERSCAN_FULL_BOX) {
+        } else if (p_loc->box_hsize == HDRL_OVERSCAN_FULL_BOX) {
             hdrl_overscan_compute_chi_square(overscan_sub_ima,
-                            ccd_ron_ima, corr, &chi2, &red_chi2);
-        }
-        else {
+                    ccd_ron_ima, corr, &chi2, &red_chi2);
+        } else {
             /*Calculate the chi2 only in the central slice of the image
              * TODO very inefficient - restructure */
             cpl_size nx = cpl_image_get_size_x(overscan_sub_ima);
             cpl_size ny = cpl_image_get_size_y(overscan_sub_ima);
 
             cpl_image * overscan_sub_ima_slice =
-                            cpl_image_extract(overscan_sub_ima, 1,
-                                            (cpl_size)((ny+1)/2), nx,
-                                            (cpl_size)((ny+1)/2));
-            cpl_image * ccd_ron_ima_slice =
-                            cpl_image_extract(ccd_ron_ima, 1,
-                                            (cpl_size)((ny+1)/2), nx,
-                                            (cpl_size)((ny+1)/2));
+                cpl_image_extract(overscan_sub_ima, 1, (cpl_size)((ny+1)/2), 
+                        nx, (cpl_size)((ny+1)/2));
+            cpl_image * ccd_ron_ima_slice = 
+                cpl_image_extract(ccd_ron_ima, 1, (cpl_size)((ny+1)/2), nx,
+                        (cpl_size)((ny+1)/2));
 
-            hdrl_overscan_compute_chi_square(overscan_sub_ima_slice,
-                            ccd_ron_ima_slice, corr, &chi2, &red_chi2);
+            hdrl_overscan_compute_chi_square(overscan_sub_ima_slice, 
+                    ccd_ron_ima_slice, corr, &chi2, &red_chi2);
 
             cpl_image_delete(overscan_sub_ima_slice);
             cpl_image_delete(ccd_ron_ima_slice);
@@ -805,13 +816,12 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
 
         cpl_image_delete(overscan_sub_ima);
         cpl_image_delete(ccd_ron_ima);
-    }
 
-    hdrl_collapse_imagelist_to_vector_delete(reduce);
+        hdrl_collapse_imagelist_to_vector_delete(reduce);
+    }
 
     /* broadcast the full box result to the full result row/col */
     if (p_loc->box_hsize == HDRL_OVERSCAN_FULL_BOX) {
-        double chi2, red_chi2;
         int rej;
         const double ccd_ron = p_loc->ccd_ron;
         const double correction_value =
@@ -821,8 +831,10 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         const cpl_size contribution_value =
                         cpl_image_get(contribution_img, 1, 1, &rej);
         cpl_size loopmax = cpl_image_get_size_y(correction_img);
+HDRL_OMP(omp parallel for private(rej))
         for (cpl_size i = 1; i <= loopmax; i++) {
-            cpl_image * overscan_sub_ima;
+            double chi2, red_chi2;
+            cpl_image * overscan_sub_ima, * ccd_ron_ima;
 
             if (i < loopmax) {
                 /*Here we broadcast*/
@@ -830,11 +842,12 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
                 cpl_image_set(correction_err_img, 1, i + 1, 
                         correction_err_value);
                 cpl_image_set(contribution_img, 1, i + 1,contribution_value);
-                if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-                    cpl_image_set(sigclip_reject_low, 1, i + 1,
-                            cpl_image_get(sigclip_reject_low, 1, 1, &rej));
-                    cpl_image_set(sigclip_reject_high, 1, i + 1,
-                            cpl_image_get(sigclip_reject_high, 1, 1, &rej));
+                if (hdrl_collapse_parameter_is_sigclip(cpse) ||
+                                hdrl_collapse_parameter_is_minmax(cpse)) {
+                    cpl_image_set(reject_low, 1, i + 1,
+                            cpl_image_get(reject_low, 1, 1, &rej));
+                    cpl_image_set(reject_high, 1, i + 1,
+                            cpl_image_get(reject_high, 1, 1, &rej));
                 }
             }
             /* Here we do additional chi2 calculation */
@@ -855,7 +868,6 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
             cpl_image_set(red_chi2_img, 1, i, red_chi2);
             cpl_image_delete(overscan_sub_ima);
             cpl_image_delete(ccd_ron_ima);
-
         }
     }
 
@@ -865,9 +877,10 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
     cpl_image_reject_value(correction_err_img, CPL_VALUE_NAN);
     cpl_image_reject_value(chi2_img, CPL_VALUE_NAN);
     cpl_image_reject_value(red_chi2_img, CPL_VALUE_NAN);
-    if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-        cpl_image_reject_value(sigclip_reject_low, CPL_VALUE_NAN);
-        cpl_image_reject_value(sigclip_reject_high, CPL_VALUE_NAN);
+    if (hdrl_collapse_parameter_is_sigclip(cpse) ||
+                    hdrl_collapse_parameter_is_minmax(cpse)) {
+        cpl_image_reject_value(reject_low, CPL_VALUE_NAN);
+        cpl_image_reject_value(reject_high, CPL_VALUE_NAN);
     }
 
     /* Handle Orientation */
@@ -877,12 +890,13 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         cpl_image_turn(contribution_img, +1);
         cpl_image_turn(chi2_img, +1);
         cpl_image_turn(red_chi2_img, +1);
-        if (hdrl_collapse_parameter_is_sigclip(cpse)) {
-            cpl_image_turn(sigclip_reject_low, +1);
-            cpl_image_turn(sigclip_reject_high, +1);
+        if (hdrl_collapse_parameter_is_sigclip(cpse) ||
+                        hdrl_collapse_parameter_is_minmax(cpse)) {
+            cpl_image_turn(reject_low, +1);
+            cpl_image_turn(reject_high, +1);
         }
     }
-    
+
     /* Create the Overscan resulting structure */
     {
         hdrl_overscan_compute_result * result =
@@ -896,8 +910,8 @@ hdrl_overscan_compute_result * hdrl_overscan_compute(
         result->contribution = contribution_img;
         result->chi2 = chi2_img;
         result->red_chi2 = red_chi2_img;
-        result->sigclip_reject_low = sigclip_reject_low;
-        result->sigclip_reject_high = sigclip_reject_high;
+        result->sigclip_reject_low = reject_low;
+        result->sigclip_reject_high = reject_high;
         return result;
     }
 }
@@ -1035,9 +1049,9 @@ cpl_image * hdrl_overscan_compute_result_get_sigclip_reject_low(
     cpl_ensure(res, CPL_ERROR_NULL_INPUT, NULL);
     if (!res->sigclip_reject_low) {
         cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
-                              "sigclip rejection parameters are only "
+                              "rejection parameters are only "
                               "available if collapse mode of overscan is set "
-                              "to sigclip");
+                              "to sigclip or minmax");
     }
     return res->sigclip_reject_low;
 }
@@ -1056,9 +1070,9 @@ cpl_image * hdrl_overscan_compute_result_unset_sigclip_reject_low(
     cpl_image * r = res->sigclip_reject_low;
     if (!res->sigclip_reject_low) {
         cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
-                              "sigclip rejection parameters are only "
+                              "rejection parameters are only "
                               "available if collapse mode of overscan is set "
-                              "to sigclip");
+                              "to sigclip or minmax");
     }
     res->sigclip_reject_low = NULL;
     return r;
@@ -1075,6 +1089,12 @@ cpl_image * hdrl_overscan_compute_result_get_sigclip_reject_high(
         const hdrl_overscan_compute_result * res)
 {
     cpl_ensure(res, CPL_ERROR_NULL_INPUT, NULL);
+    if (!res->sigclip_reject_high) {
+        cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
+                              "rejection parameters are only "
+                              "available if collapse mode of overscan is set "
+                              "to sigclip or minmax");
+    }
     return res->sigclip_reject_high;
 }
 
@@ -1094,6 +1114,61 @@ cpl_image * hdrl_overscan_compute_result_unset_sigclip_reject_high(
     return r;
 }
 
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Access the low threshold in the Overscan Computation result object
+  @param    res The Overscan Computation result object
+  @return   The low threshold CPL image
+ */
+/*----------------------------------------------------------------------------*/
+cpl_image * hdrl_overscan_compute_result_get_minmax_reject_low(
+        const hdrl_overscan_compute_result * res)
+{
+   return hdrl_overscan_compute_result_get_sigclip_reject_low(res);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Unset the low threshold in the Overscan Computation result object
+  @param    res The Overscan Computation result object
+  @return   The low threshold CPL image that has been unset
+ */
+/*----------------------------------------------------------------------------*/
+cpl_image * hdrl_overscan_compute_result_unset_minmax_reject_low(
+        hdrl_overscan_compute_result * res)
+{
+    return hdrl_overscan_compute_result_unset_sigclip_reject_low(res);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Access the high threshold in the Overscan Computation result object
+  @param    res The Overscan Computation result object
+  @return   The high threshold CPL image
+ */
+/*----------------------------------------------------------------------------*/
+cpl_image * hdrl_overscan_compute_result_get_minmax_reject_high(
+        const hdrl_overscan_compute_result * res)
+{
+    return hdrl_overscan_compute_result_get_sigclip_reject_high(res);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Unset the high threshold in the Overscan Computation result object
+  @param    res The Overscan Computation result object
+  @return   The high threshold CPL image that has been unset
+ */
+/*----------------------------------------------------------------------------*/
+cpl_image * hdrl_overscan_compute_result_unset_minmax_reject_high(
+        hdrl_overscan_compute_result * res)
+{
+    return hdrl_overscan_compute_result_unset_sigclip_reject_high(res);
+}
+
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Deletes the Overscan Computation Result Structure
@@ -1119,7 +1194,6 @@ void hdrl_overscan_compute_result_delete(
   @brief    Overscan correction 
   @param    hsource         Input HDRL image that needs to be corrected
   @param    region          Region from source that needs correction
-  @param    reject_code     integer to use as bad pixel code
   @param    os_computation  Results of the Overscan computation
   @return  hdrl_overscan_correct_result structure containing the
   results of the correction. It must be freed with 
@@ -1137,17 +1211,13 @@ void hdrl_overscan_compute_result_delete(
   If NULL or invalid, the whole image is corrected.
   The region size must fit the sixe of the os_computation.
 
-  reject_code must be a power of two integer which is used as value for
-  pixels the algorithm considers bad in the bad pixel bitmask of the result.
-
   os_computation contains all the parameters for the overscan
   correction. It has been produced by hdrl_overscan_compute().
 
-  The output hdrl_overscan_correct_result structure (in the following
-  named 'out') contains the following members:
+  Following results are available from the return value:
 
-  out.ima_corrected is a HDRL image of type double of the same size as
-  source.
+  hdrl_overscan_correct_result_get_corrected(result):
+  returns the HDRL image of type double of the same size as source.
   
   Its image part contains the corrected values where all the pixels
   within the specified region were subtracted using the proper correction 
@@ -1157,17 +1227,21 @@ void hdrl_overscan_compute_result_delete(
   pixels in the overscan region are bad) are set to zero.
 
   Its error part contains the error where all the pixels within the specified 
-  region are set to: sqrt(os_computation.error^2 *  + source_error^2), which is
+  region are set to: \f$\sqrt{(os\_computation.error^2 + source\_error^2)}\f$, which is
   the standard Gaussian error propagation.
   The pixels outside the specified region remain unchanged.
   Pixels for which a overscan value could not be determined (e.g. because all
   pixels in the overscan region are bad) are set to zero.
+
+  hdrl_overscan_correct_result_get_badmask(result):
+  returns an integer cpl_image of the same size as the input that contains a
+  value of 1 for pixels that have not been corrected due to the overscan data
+  being bad in that row/column.
  */
 /*----------------------------------------------------------------------------*/
 hdrl_overscan_correct_result * hdrl_overscan_correct(
         const hdrl_image                    *   hsource,
         const hdrl_parameter                *   region,
-        const hdrl_bitmask_t                    reject_code,
         const hdrl_overscan_compute_result  *   os_computation)
 {
     cpl_size            llx = 0, lly = 0, urx = 0, ury = 0;
@@ -1179,6 +1253,8 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
     size_t              nx;
     cpl_mask        *   orig_mask = NULL;
     hdrl_image      *   hoverscan;
+    /* value to use in mask for pixels rejected by algorithm */
+    hdrl_bitmask_t      reject_code = 1;
 
     /* Check Entries */
     cpl_error_ensure(hsource != NULL, CPL_ERROR_NULL_INPUT,
@@ -1212,12 +1288,10 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
     }
 
     source_loc =
-        cpl_image_cast(hdrl_image_get_image_const(hsource), CPL_TYPE_DOUBLE);
+        cpl_image_cast(hdrl_image_get_image_const(hsource), HDRL_TYPE_DATA);
     source_error_loc =
-        cpl_image_cast(hdrl_image_get_error_const(hsource), CPL_TYPE_DOUBLE);
+        cpl_image_cast(hdrl_image_get_error_const(hsource), HDRL_TYPE_ERROR);
     nx = cpl_image_get_size_x(source_loc);
-    /* store original mask to later separate it from newly created bpms */
-    orig_mask = hdrl_copy_image_mask(source_loc);
 
     xsize_overscan = hdrl_image_get_size_x(hoverscan);
     ysize_overscan = hdrl_image_get_size_y(hoverscan);
@@ -1227,7 +1301,7 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
             ury-lly+1 != ysize_overscan) {
         cpl_image_delete(source_loc);
         cpl_image_delete(source_error_loc);
-        cpl_error_set_message(cpl_func,CPL_ERROR_ILLEGAL_INPUT,
+        cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
                 "Correction region Y size does not match overscan Y size");
         return NULL;
     }
@@ -1235,14 +1309,24 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
             urx-llx+1 != xsize_overscan) {
         cpl_image_delete(source_loc);
         cpl_image_delete(source_error_loc);
-        cpl_error_set_message(cpl_func,CPL_ERROR_ILLEGAL_INPUT,
+        cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
                 "Correction region X size does not match overscan X size");
         return NULL;
     }
 
+    if (xsize_overscan != 1 && ysize_overscan != 1) {
+        cpl_image_delete(source_loc);
+        cpl_image_delete(source_error_loc);
+        cpl_error_set(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT);
+        return NULL;
+    }
+
+    /* store original mask to later separate it from newly created bpms */
+    orig_mask = hdrl_copy_image_mask(source_loc);
+
     {
-        double * psource_loc = cpl_image_get_data_double(source_loc);
-        double * psource_err_loc = cpl_image_get_data_double(source_error_loc);
+        hdrl_data_t * psource_loc = cpl_image_get_data(source_loc);
+        hdrl_error_t * psource_err_loc = cpl_image_get_data(source_error_loc);
         const cpl_mask * bpm = hdrl_image_get_mask_const(hoverscan);
         /* os image is one dimensional, so just get the data */
         const cpl_binary * rej = bpm ?  cpl_mask_get_data_const(bpm) : NULL;
@@ -1250,12 +1334,12 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
                                      hdrl_image_get_image_const(hoverscan));
         const hdrl_error_t * pos_e = hdrl_get_image_error_const(
                                      hdrl_image_get_error_const(hoverscan));
-        cpl_ensure(hdrl_image_get_size_x(hoverscan) == 1 ||
-                   hdrl_image_get_size_y(hoverscan) == 1,
-                   CPL_ERROR_INCOMPATIBLE_INPUT, NULL);
+        /* make sure we have a bpm before the parallel loop */
+        cpl_image_get_bpm(source_loc);
 
         /* corrects extracted image for over-scan value, compute associated
          * error, flag bad pixels */
+HDRL_OMP(omp parallel for)
         for (long j = lly - 1; j < ury; j++) {
             for (long i = llx - 1; i < urx; i++) {
                 const size_t idx = 
@@ -1294,11 +1378,8 @@ hdrl_overscan_correct_result * hdrl_overscan_correct(
 
         /* Create, fill and return the returned structure */
         res = hdrl_overscan_correct_result_create();
-        /* only data has bpm */
-        cpl_image_accept_all(source_error_loc);
-        res->corrected = hdrl_image_create(source_loc, source_error_loc);
-        cpl_image_delete(source_loc);
-        cpl_image_delete(source_error_loc);
+        res->corrected = hdrl_image_wrap(source_loc, source_error_loc, NULL,
+                                         CPL_TRUE);
         res->badmask = badmask;
         return res;
     }
@@ -1609,12 +1690,12 @@ static cpl_error_code hdrl_overscan_reduce_image_to_scalar(
         double                              *   result, 
         double                              *   error,
         cpl_size                            *   contribution,
-        void                                *   eout)
+        void                                **  eout)
 {
     cpl_imagelist * ld = cpl_imagelist_new();
     cpl_imagelist * le = cpl_imagelist_new();
-    cpl_vector * od, * oe;
-    cpl_array * oc;
+    cpl_vector * od = NULL, * oe = NULL;
+    cpl_array * oc = NULL;
     cpl_error_code fail;
     cpl_imagelist_set(ld, data, 0);
     cpl_imagelist_set(le, data_error, 0);
