@@ -775,6 +775,7 @@ cpl_error_code hdrl_kappa_sigma_clip(
         vec_image_err = cpl_vector_duplicate(vec_err);
     }
     double * vec_data = cpl_vector_get_data(vec_image);
+    double * vec_data_orig = vec_data;
     double * vec_data_err = cpl_vector_get_data(vec_image_err);
     vec_size = cpl_vector_get_size(vec_image);
 
@@ -805,10 +806,10 @@ cpl_error_code hdrl_kappa_sigma_clip(
         /* standard deviation from Median Absolute Deviation (MAD) as appropriate
            for a Gaussian distribution */
 
-       /* TODO remove image wrapper once a cpl_vector_get_mad() exists */
-        cpl_image * ima_vectorwrap = cpl_image_wrap_double(vec_size, 1,vec_data);
-        median = cpl_image_get_mad(ima_vectorwrap, &sigma);
-        cpl_image_unwrap(ima_vectorwrap);
+        /* offset index into original uncut vec_image */
+        cpl_size orig_offset = (cpl_size)(vec_data - vec_data_orig) + 1;
+        median = hcpl_vector_get_mad_window(vec_image, orig_offset,
+                                            orig_offset + vec_size - 1, &sigma);
 
         if(sigma <= 0){
             sigma=nextafter(0,1.0);
