@@ -26,8 +26,8 @@
  -----------------------------------------------------------------------------*/
 
 #include "hdrl_combine.h"
+#include "hdrl_iter.h"
 #include "hdrl_types.h"
-
 #include <cpl.h>
 
 #include <math.h>
@@ -67,7 +67,12 @@ _hdrl_image_get(cpl_image * img, cpl_size x, cpl_size y, int * rej)
     double v = cpl_image_get(img, x, y, rej);
     if (*rej) {
         size_t nx = cpl_image_get_size_x(img);
-        v = cpl_image_get_data_double(img)[(y - 1) * nx + (x - 1)];
+        if (cpl_image_get_type(img) == CPL_TYPE_DOUBLE) {
+            v = cpl_image_get_data_double(img)[(y - 1) * nx + (x - 1)];
+        }
+        else {
+            v = cpl_image_get_data_float(img)[(y - 1) * nx + (x - 1)];
+        }
     }
     return v;
 }
@@ -164,12 +169,15 @@ void test_l2i_and_l2v(cpl_imagelist * data,
                                            NULL);
     cpl_imagelist_delete(vl);
     cpl_imagelist_delete(el);
-
-	hdrl_test_abs(cpl_vector_get(voutimg, 0), v.v1, v.v2, -1);
-	hdrl_test_abs(cpl_vector_get(vouterr, 0), e.v1, e.v2, -1);
-
-	cpl_test_abs(cpl_array_get_int(acontrib, 0, NULL),
-				 cpl_image_get(expcontrib, x, y, &d), 0);
+    if (voutimg) {
+        hdrl_test_abs(cpl_vector_get(voutimg, 0), v.v1, v.v2, -1);
+        hdrl_test_abs(cpl_vector_get(vouterr, 0), e.v1, e.v2, -1);
+        cpl_test_abs(cpl_array_get_int(acontrib, 0, NULL),
+                     cpl_image_get(expcontrib, x, y, &d), 0);
+    }
+    else {
+        cpl_test_abs(cpl_image_get(expcontrib, x, y, &d), 0, 0);
+    }
 
     cpl_vector_delete(voutimg);
     cpl_vector_delete(vouterr);
@@ -211,90 +219,26 @@ void test_parlist(void)
         hdrl_collapse_sigclip_parameter_create(1., 2., 5);
     hdrl_parameter * minmax_def =
         hdrl_collapse_minmax_parameter_create(1., 1.);
-
-    cpl_parameterlist *parlist = hdrl_collapse_parameter_create_parlist(
-                 "RECIPE", "collapse", "UNKNOWN", sigclip_def, minmax_def) ;
-     cpl_test_error(CPL_ERROR_NONE);
-
-     cpl_parameterlist *parlist1 = hdrl_collapse_parameter_create_parlist(
-                  "RECIPE", "collapse", "MEAN", sigclip_def, minmax_def) ;
-      cpl_test_error(CPL_ERROR_NONE);
-
-      cpl_parameterlist *parlist2 = hdrl_collapse_parameter_create_parlist(
-                "RECIPE", "collapse", "WEIGHTED_MEAN", sigclip_def, minmax_def) ;
-    cpl_test_error(CPL_ERROR_NONE);
-
-    cpl_parameterlist *parlist3 = hdrl_collapse_parameter_create_parlist(
-                "RECIPE", "collapse", "MEDIAN", sigclip_def, minmax_def) ;
-    cpl_test_error(CPL_ERROR_NONE);
-
-    cpl_parameterlist *parlist4 = hdrl_collapse_parameter_create_parlist(
+    cpl_parameterlist * parlist = hdrl_collapse_parameter_create_parlist(
                 "RECIPE", "collapse", "SIGCLIP", sigclip_def, minmax_def) ;
-    cpl_test_error(CPL_ERROR_NONE);
-    cpl_test_eq(cpl_parameterlist_get_size(parlist4), 6);
-
     hdrl_parameter_delete(sigclip_def);
     hdrl_parameter_delete(minmax_def);
+    cpl_test_error(CPL_ERROR_NONE);
+    cpl_test_eq(cpl_parameterlist_get_size(parlist), 6);
 
-
-    /* UNKNOWN */
-/*    hpar = hdrl_collapse_parameter_parse_parlist(parlist, "RECIPE.invalid");
+    hpar = hdrl_collapse_parameter_parse_parlist(parlist, "RECIPE.invalid");
     cpl_test_null(hpar);
     cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
+
     hpar = hdrl_collapse_parameter_parse_parlist(parlist, "RECIPE.collapse");
     cpl_test_error(CPL_ERROR_NONE);
-    hdrl_parameter_delete(hpar);
-*/
-    /* MEAN */
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist1, "RECIPE.invalid");
-    cpl_test_null(hpar);
-    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist1, "RECIPE.collapse");
-    cpl_test_error(CPL_ERROR_NONE);
-    hdrl_parameter_delete(hpar);
-
-
-    /* WEIGHTED_MEAN */
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist2, "RECIPE.invalid");
-    cpl_test_null(hpar);
-    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist2, "RECIPE.collapse");
-    cpl_test_error(CPL_ERROR_NONE);
-    hdrl_parameter_delete(hpar);
-
-
-    /* MEDIAN */
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist3, "RECIPE.invalid");
-    cpl_test_null(hpar);
-    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist3, "RECIPE.collapse");
-    cpl_test_error(CPL_ERROR_NONE);
-    hdrl_parameter_delete(hpar);
-
-
-    /* SIGCLIP */
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist4, "RECIPE.invalid");
-    cpl_test_null(hpar);
-    cpl_test_error(CPL_ERROR_DATA_NOT_FOUND);
-    hpar = hdrl_collapse_parameter_parse_parlist(parlist4, "RECIPE.collapse");
-    cpl_test_error(CPL_ERROR_NONE);
-
     cpl_test(hdrl_collapse_parameter_is_sigclip(hpar));
     cpl_test(!hdrl_collapse_parameter_is_median(hpar));
     cpl_test_eq(hdrl_collapse_sigclip_parameter_get_kappa_high(hpar), 2.);
     cpl_test_eq(hdrl_collapse_sigclip_parameter_get_kappa_low(hpar), 1.);
     cpl_test_eq(hdrl_collapse_sigclip_parameter_get_niter(hpar), 5);
-
     hdrl_parameter_delete(hpar);
-
-
-    /* Clean up */
-    cpl_parameterlist_delete(parlist );
-    cpl_parameterlist_delete(parlist1);
-    cpl_parameterlist_delete(parlist2);
-    cpl_parameterlist_delete(parlist3);
-    cpl_parameterlist_delete(parlist4);
-
+    cpl_parameterlist_delete(parlist);
 
     hpar = hdrl_collapse_mean_parameter_create();
     cpl_test(hdrl_collapse_parameter_is_mean(hpar));
@@ -308,72 +252,6 @@ void test_parlist(void)
 }
 
 
-void test_eout(void)
-{
-    cpl_size n = 40;
-
-
-	/* Method with vector mean */
-    hdrl_collapse_imagelist_to_vector_t * vMethod1;
-    vMethod1 = hdrl_collapse_imagelist_to_vector_mean();
-
-    void *eout1 = hdrl_collapse_imagelist_to_vector_create_eout(vMethod1, n);
-
-    void *eout2 = NULL;
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod1, eout1, eout2, n);
-
-    hdrl_collapse_imagelist_to_vector_delete_eout(vMethod1, eout2);
-	hdrl_collapse_imagelist_to_vector_delete_eout(vMethod1, eout1);
-    hdrl_collapse_imagelist_to_vector_delete(vMethod1);
-
-
-	/* Method with vector minmax */
-	hdrl_collapse_imagelist_to_vector_t *vMethod2;
-	vMethod2 = hdrl_collapse_imagelist_to_vector_minmax(3., 3.);
-
-    void *eout3 = hdrl_collapse_imagelist_to_vector_create_eout(vMethod2, n);
-
-    hdrl_collapse_imagelist_to_vector_delete_eout(vMethod2, eout3);
-	hdrl_collapse_imagelist_to_vector_delete(vMethod2);
-
-
-	/* Method with vector sigclip */
-	hdrl_collapse_imagelist_to_vector_t *vMethod3;
-	vMethod3 = hdrl_collapse_imagelist_to_vector_sigclip(3., 3., 3);
-
-    void *eout4 = hdrl_collapse_imagelist_to_vector_create_eout(vMethod3, n);
-    void *eout5 = hdrl_collapse_imagelist_to_vector_create_eout(vMethod3, n);
-
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, NULL, eout5, n);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, eout4, NULL, n);
-    cpl_test_error(CPL_ERROR_NULL_INPUT);
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, eout4, eout4, n);
-    cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, eout4, eout5, n);
-    cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, eout5, eout4, n);
-    cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
-    hdrl_collapse_imagelist_to_vector_move_eout(vMethod3, eout5, eout5, n);
-    cpl_test_error(CPL_ERROR_ACCESS_OUT_OF_RANGE);
-
-    hdrl_collapse_imagelist_to_vector_delete_eout(vMethod3, eout4);
-	hdrl_collapse_imagelist_to_vector_delete_eout(vMethod3, eout5);
-	hdrl_collapse_imagelist_to_vector_delete(vMethod3);
-
-
-	/* Method with image */
-    hdrl_collapse_imagelist_to_image_t *vMethod4;
-    vMethod4 = hdrl_collapse_imagelist_to_image_sigclip(3., 3., 3);
-
-    cpl_image *img = cpl_image_new(10, 10, CPL_TYPE_DOUBLE);
-    void *eout6 = hdrl_collapse_imagelist_to_image_create_eout(vMethod4, img);
-	cpl_image_delete(img);
-
-	hdrl_collapse_imagelist_to_image_delete_eout(vMethod4, eout6);
-	hdrl_collapse_imagelist_to_image_delete(vMethod4);
-}
-
 /*----------------------------------------------------------------------------*/
 /**
  @brief   Unit tests of reduce module
@@ -385,7 +263,6 @@ int main(void)
 
     test_parameters();
     test_parlist();
-    test_eout();
 
 #define TST_FREE \
         cpl_image_delete(outimg); outimg = NULL; \
@@ -394,7 +271,8 @@ int main(void)
         cpl_vector_delete(voutimg); voutimg = NULL; \
         cpl_vector_delete(vouterr); vouterr = NULL; \
         cpl_array_delete(acontrib); acontrib = NULL; \
-        hdrl_collapse_imagelist_to_image_delete(method);
+        hdrl_collapse_imagelist_to_image_delete(method); method = NULL;
+        //hdrl_collapse_imagelist_to_vector_delete(vmethod); method = NULL;
 
     /* create data, value 5., error +-1 */
     cpl_imagelist * data = cpl_imagelist_new();
@@ -763,10 +641,9 @@ int main(void)
         hdrl_collapse_imagelist_to_vector_call(vmethod, vl, el,
                                                &voutimg, &vouterr, &acontrib,
                                                NULL);
-
-        cpl_test_abs(cpl_vector_get(voutimg, 0), 1.5, HDRL_EPS_DATA);
-        cpl_test_abs(cpl_vector_get(vouterr, 0), 1. / sqrt(2.), HDRL_EPS_ERROR);
-
+        hdrl_test_abs(cpl_vector_get(voutimg, 0), 1.5, HDRL_EPS_DATA, -1);
+        hdrl_test_abs(cpl_vector_get(vouterr, 0), 1. / sqrt(2.),
+                      HDRL_EPS_ERROR, -1);
         cpl_test_abs(cpl_array_get_int(acontrib, 0, NULL), 2, 0);
         cpl_vector_delete(voutimg);
         cpl_vector_delete(vouterr);
@@ -778,11 +655,9 @@ int main(void)
         hdrl_collapse_imagelist_to_vector_call(vmethod, vl, el,
                                                &voutimg, &vouterr, &acontrib,
                                                NULL);
-
-        cpl_test_abs(cpl_vector_get(voutimg, 0), 2., HDRL_EPS_DATA);
-        cpl_test_abs(cpl_vector_get(vouterr, 0),
-        		1. / sqrt(nz) * sqrt(CPL_MATH_PI_2), HDRL_EPS_ERROR);
-
+        hdrl_test_abs(cpl_vector_get(voutimg, 0), 2., HDRL_EPS_DATA, -1);
+        hdrl_test_abs(cpl_vector_get(vouterr, 0),
+                      1. / sqrt(nz) * sqrt(CPL_MATH_PI_2), HDRL_EPS_ERROR, -1);
         cpl_test_abs(cpl_array_get_int(acontrib, 0, NULL), 5, 0);
         cpl_imagelist_delete(vl);
         cpl_imagelist_delete(el);
