@@ -34,6 +34,7 @@
 #include <cpl.h>
 #include <moses.h>
 #include <fors_dfs.h>
+#include <fors_utils.h>
 
 static int fors_extract_create(cpl_plugin *);
 static int fors_extract_exec(cpl_plugin *);
@@ -131,7 +132,7 @@ cpl_table_delete(slits);                      \
 cpl_table_delete(wavelengths);                \
 cpl_vector_delete(lines);                     \
 cpl_msg_indent_less();                        \
-return -1;                                    \
+return fors_get_error_for_exit();             \
 }
 
 
