@@ -803,13 +803,13 @@ static int fors_pmos_extract(cpl_parameterlist *parlist, cpl_frameset *frameset)
     cpl_msg_indent_more();
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_pmos_extract_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_pmos_extract_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID"))
-        fors_pmos_extract_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
     standard = 0;
     pmos = cpl_frameset_count_tags(frameset, "SCIENCE_PMOS");
@@ -1739,7 +1739,7 @@ End old saving */
 	    cpl_msg_info(recipe, "Extracting at angle %.2f (%d out of %d) ...",
 			 angles[j], j + 1, nscience);
 
-	    images = mos_extract_objects(mappeds[j], skylocalmaps[j],
+	    images = mos_extract_objects(mappeds[j], NULL, skylocalmaps[j],
 					 origslits, 
 					 ext_mode, ron, gain, 1);
 
