@@ -271,7 +271,7 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
     }
 
     //Get master bias
-    std::auto_ptr<fors::fiera_config> bias_ccd_config;  
+    std::unique_ptr<fors::fiera_config> bias_ccd_config;  
     if(nbias == 1)
     {
         cpl_msg_info(recipe, "Load master bias");
@@ -337,7 +337,7 @@ static int fors_remove_bias(cpl_parameterlist *parlist,
         {
             cpl_error_set_message(cpl_func, CPL_ERROR_INCOMPATIBLE_INPUT,
                     "Master bias overscan configuration doesn't match science");
-            return NULL;
+            fors_remove_bias_exit(NULL);
         }
 
         /* Create variance */
