@@ -844,7 +844,7 @@ static int fors_wave_calib_lss(cpl_parameterlist *parlist,
         if (!cpl_table_is_valid(idscoeff, "c0", i))
             cpl_table_set_invalid(idscoeff, "error", i);
 
-    cpl_msg_info(recipe, "Valid solutions found: %d out of %d rows",
+    cpl_msg_info(recipe, "Valid solutions found: %ld out of %ld rows",
                  ny - cpl_table_count_invalid(idscoeff, "c0"), ny);
 
     cpl_image_delete(spectra); spectra = NULL;
