@@ -86,8 +86,9 @@ try:
                                                flat_norm, curv_frame)
 
       #Update the parameters
-      requested_lines = self.getCurrentParameterHelper('ignore_lines')
-      self.mapping_ignored_real = self.mapIgnoredRealLines(requested_lines)
+      if self.disp_residuals is not None:
+        requested_lines = self.getCurrentParameterHelper('ignore_lines')
+        self.mapping_ignored_real = self.mapIgnoredRealLines(requested_lines)
                   
     # This function creates all the subplots. It is responsible for the plotting 
     # layouts. 
