@@ -154,7 +154,11 @@ class PlotableMappedScience :
     #Reading the object table
     if self.objecttable is not None:
       nslit = self.objecttable.getTableNrows(1)
-      maxobjectperslit = (self.objecttable.getTableNcols(1) - 7 ) / 6
+      n_object_cols = 0
+      for col in self.objecttable.all_hdu[1].data.columns:
+        if "object" in col.name:
+          n_object_cols = n_object_cols + 1
+      maxobjectperslit = n_object_cols
       start_extracted_cols = []
       end_extracted_cols = []
       for obj in range(maxobjectperslit):
