@@ -134,7 +134,7 @@ which will be plotted below."""
                              tooltip_sci_mapped)
 
     def plotSciExtracted(self) :
-        title_sci_extracted = 'Extracted science spectrum (not flux-calibrated)'
+        title_sci_extracted = 'Extracted science spectrum (not flux-calibrated) #' + str(self.sci_extracted.obj_id)
         tooltip_sci_extracted ="""Extracted science spectrum (not flux-calibrated).
 This is the sky-subtracted spectrum as extracted by the pipeline."""
         self.subplot_sci_extracted.clear()
@@ -247,8 +247,8 @@ a constant shift (--skyalign parameter)."""
       paramList.append(reflex.RecipeParameter('fors_science','skyglobal',group='Sky subtraction',description='Subtract global sky spectrum from CCD'))
       paramList.append(reflex.RecipeParameter('fors_science','skymedian',group='Sky subtraction',description='Sky subtraction from extracted slit spectra'))
       paramList.append(reflex.RecipeParameter('fors_science','skylocal',group='Sky subtraction',description='Sky subtraction from CCD slit spectra'))
-      paramList.append(reflex.RecipeParameter('fors_science','cosmics',group='Sky subtraction',description='Eliminate cosmic rays hits (only if global sky subtraction is also requested)'))
-      paramList.append(reflex.RecipeParameter('fors_science','slit_margin',group='Spectra extraction',description='Number of pixels to exclude at each slit in object detection and extraction.'))
+      paramList.append(reflex.RecipeParameter('fors_science','cosmics',group='Sky subtraction',description='Eliminate cosmic rays hits, only if either global or local sky (not for LSS) subtraction is also requested'))
+      paramList.append(reflex.RecipeParameter('fors_science','slit_margin',group='Spectra extraction',description='Number of pixels to exclude at each slit in object detection and extraction'))
       paramList.append(reflex.RecipeParameter('fors_science','ext_radius',group='Spectra extraction',description='Maximum extraction radius for detected objects (pixel)'))
       paramList.append(reflex.RecipeParameter('fors_science','cont_radius',group='Spectra extraction',description='Minimum distance at which two objects of equal luminosity do not contaminate each other (pixel)'))
       paramList.append(reflex.RecipeParameter('fors_science','ext_mode',group='Spectra extraction',description='Object extraction method: 0 = aperture, 1 = Horne optimal extraction'))
